@@ -142,6 +142,8 @@ let package = Package(
         "src/crypto/kyber/kyber.c",
         "src/crypto/lhash/lhash.c",
         "src/crypto/mem.c",
+        "src/crypto/mldsa/mldsa.c",
+        "src/crypto/mlkem/mlkem.cc",
         "src/crypto/obj/obj.c",
         "src/crypto/obj/obj_xref.c",
         "src/crypto/pem/pem_all.c",
@@ -162,12 +164,14 @@ let package = Package(
         "src/crypto/poly1305/poly1305_vec.c",
         "src/crypto/pool/pool.c",
         "src/crypto/rand_extra/deterministic.c",
+        "src/crypto/rand_extra/fork_detect.c",
         "src/crypto/rand_extra/forkunsafe.c",
         "src/crypto/rand_extra/getentropy.c",
         "src/crypto/rand_extra/ios.c",
         "src/crypto/rand_extra/passive.c",
         "src/crypto/rand_extra/rand_extra.c",
         "src/crypto/rand_extra/trusty.c",
+        "src/crypto/rand_extra/urandom.c",
         "src/crypto/rand_extra/windows.c",
         "src/crypto/rc4/rc4.c",
         "src/crypto/refcount.c",
