@@ -233,10 +233,9 @@ void TransportFlowControl::UpdateSetting(
     FlowControlAction& (FlowControlAction::*set)(FlowControlAction::Urgency,
                                                  uint32_t)) {
   if (new_desired_value != *desired_value) {
-    if (GRPC_TRACE_FLAG_ENABLED(flowctl)) {
-      LOG(INFO) << "[flowctl] UPDATE SETTING " << name << " from "
-                << *desired_value << " to " << new_desired_value;
-    }
+    GRPC_TRACE_LOG(flowctl, INFO)
+        << "[flowctl] UPDATE SETTING " << name << " from " << *desired_value
+        << " to " << new_desired_value;
     // Reaching zero can only happen for initial window size, and if it occurs
     // we really want to wake up writes and ensure all the queued stream
     // window updates are flushed, since stream flow control operates
