@@ -93,10 +93,9 @@ grpc_error_handle grpc_chttp2_ping_parser_parse(void* parser,
   if (p->byte == 8) {
     CHECK(is_last);
     if (p->is_ack) {
-      if (GRPC_TRACE_FLAG_ENABLED(http2_ping)) {
-        LOG(INFO) << (t->is_client ? "CLIENT" : "SERVER") << "[" << t
-                  << "]: received ping ack " << p->opaque_8bytes;
-      }
+      GRPC_TRACE_LOG(http2_ping, INFO)
+          << (t->is_client ? "CLIENT" : "SERVER") << "[" << t
+          << "]: received ping ack " << p->opaque_8bytes;
       grpc_chttp2_ack_ping(t, p->opaque_8bytes);
     } else {
       if (!t->is_client) {
@@ -111,8 +110,9 @@ grpc_error_handle grpc_chttp2_ping_parser_parse(void* parser,
         if (t->ping_abuse_policy.ReceivedOnePing(transport_idle)) {
           grpc_chttp2_exceeded_ping_strikes(t);
         }
-      } else if (GRPC_TRACE_FLAG_ENABLED(http2_ping)) {
-        LOG(INFO) << "CLIENT[" << t << "]: received ping " << p->opaque_8bytes;
+      } else {
+        GRPC_TRACE_LOG(http2_ping, INFO)
+            << "CLIENT[" << t << "]: received ping " << p->opaque_8bytes;
       }
       if (t->ack_pings) {
         if (t->ping_ack_count == t->ping_ack_capacity) {
