@@ -32,21 +32,18 @@
 static void exec_ctx_run(grpc_closure* closure) {
 #ifndef NDEBUG
   closure->scheduled = false;
-  if (GRPC_TRACE_FLAG_ENABLED(closure)) {
-    VLOG(2) << "running closure " << closure << ": created ["
-            << closure->file_created << ":" << closure->line_created
-            << "]: " << (closure->run ? "run" : "scheduled") << " ["
-            << closure->file_initiated << ":" << closure->line_initiated << "]";
-  }
+  GRPC_TRACE_VLOG(closure, 2)
+      << "running closure " << closure << ": created [" << closure->file_created
+      << ":" << closure->line_created
+      << "]: " << (closure->run ? "run" : "scheduled") << " ["
+      << closure->file_initiated << ":" << closure->line_initiated << "]";
 #endif
   grpc_error_handle error =
       grpc_core::internal::StatusMoveFromHeapPtr(closure->error_data.error);
   closure->error_data.error = 0;
   closure->cb(closure->cb_arg, std::move(error));
 #ifndef NDEBUG
-  if (GRPC_TRACE_FLAG_ENABLED(closure)) {
-    VLOG(2) << "closure " << closure << " finished";
-  }
+  GRPC_TRACE_VLOG(closure, 2) << "closure " << closure << " finished";
 #endif
 }
 
