@@ -95,10 +95,8 @@ void LockfreeEvent::NotifyOn(grpc_closure* closure) {
     // sure that the shutdown error has been initialized properly before us
     // referencing it.
     gpr_atm curr = gpr_atm_acq_load(&state_);
-    if (GRPC_TRACE_FLAG_ENABLED(polling)) {
-      VLOG(2) << "LockfreeEvent::NotifyOn: " << this << " curr=" << curr
-              << " closure=" << closure;
-    }
+    GRPC_TRACE_VLOG(polling, 2) << "LockfreeEvent::NotifyOn: " << this
+                                << " curr=" << curr << " closure=" << closure;
     switch (curr) {
       case kClosureNotReady: {
         // kClosureNotReady -> <closure>.
@@ -163,10 +161,9 @@ bool LockfreeEvent::SetShutdown(grpc_error_handle shutdown_error) {
 
   while (true) {
     gpr_atm curr = gpr_atm_no_barrier_load(&state_);
-    if (GRPC_TRACE_FLAG_ENABLED(polling)) {
-      VLOG(2) << "LockfreeEvent::SetShutdown: " << &state_ << " curr=" << curr
-              << " err=" << StatusToString(shutdown_error);
-    }
+    GRPC_TRACE_VLOG(polling, 2)
+        << "LockfreeEvent::SetShutdown: " << &state_ << " curr=" << curr
+        << " err=" << StatusToString(shutdown_error);
     switch (curr) {
       case kClosureReady:
       case kClosureNotReady:
@@ -212,9 +209,8 @@ void LockfreeEvent::SetReady() {
   while (true) {
     gpr_atm curr = gpr_atm_no_barrier_load(&state_);
 
-    if (GRPC_TRACE_FLAG_ENABLED(polling)) {
-      VLOG(2) << "LockfreeEvent::SetReady: " << &state_ << " curr=" << curr;
-    }
+    GRPC_TRACE_VLOG(polling, 2)
+        << "LockfreeEvent::SetReady: " << &state_ << " curr=" << curr;
 
     switch (curr) {
       case kClosureReady: {
