@@ -17,6 +17,7 @@
 
 #include <utility>
 
+#include "absl/functional/any_invocable.h"
 #include "absl/meta/type_traits.h"
 
 #include <grpc/support/port_platform.h>
@@ -50,19 +51,28 @@ namespace promise_detail {
 
 template <typename T>
 struct PollWrapper {
-  static Poll<T> Wrap(T&& x) { return Poll<T>(std::forward<T>(x)); }
+  GPR_ATTRIBUTE_ALWAYS_INLINE_FUNCTION static Poll<T> Wrap(T&& x) {
+    return Poll<T>(std::forward<T>(x));
+  }
 };
 
 template <typename T>
 struct PollWrapper<Poll<T>> {
-  static Poll<T> Wrap(Poll<T>&& x) { return std::forward<Poll<T>>(x); }
+  GPR_ATTRIBUTE_ALWAYS_INLINE_FUNCTION static Poll<T> Wrap(Poll<T>&& x) {
+    return std::forward<Poll<T>>(x);
+  }
 };
 
 template <typename T>
-auto WrapInPoll(T&& x) -> decltype(PollWrapper<T>::Wrap(std::forward<T>(x))) {
+GPR_ATTRIBUTE_ALWAYS_INLINE_FUNCTION auto WrapInPoll(T&& x)
+    -> decltype(PollWrapper<T>::Wrap(std::forward<T>(x))) {
   return PollWrapper<T>::Wrap(std::forward<T>(x));
 }
 
+// T -> T, const T& -> T
+template <typename T>
+using RemoveCVRef = absl::remove_cv_t<absl::remove_reference_t<T>>;
+
 template <typename F, typename SfinaeVoid = void>
 class PromiseLike;
 
@@ -79,19 +89,19 @@ class PromiseLike<F, absl::enable_if_t<!std::is_void<
 #endif
                          >::value>> {
  private:
-  GPR_NO_UNIQUE_ADDRESS F f_;
+  GPR_NO_UNIQUE_ADDRESS RemoveCVRef<F> f_;
 
  public:
   // NOLINTNEXTLINE - internal detail that drastically simplifies calling code.
-  PromiseLike(F&& f) : f_(std::forward<F>(f)) {}
-  auto operator()() -> decltype(WrapInPoll(f_())) { return WrapInPoll(f_()); }
+  GPR_ATTRIBUTE_ALWAYS_INLINE_FUNCTION PromiseLike(F&& f)
+      : f_(std::forward<F>(f)) {}
+  GPR_ATTRIBUTE_ALWAYS_INLINE_FUNCTION auto operator()()
+      -> decltype(WrapInPoll(f_())) {
+    return WrapInPoll(f_());
+  }
   using Result = typename PollTraits<decltype(WrapInPoll(f_()))>::Type;
 };
 
-// T -> T, const T& -> T
-template <typename T>
-using RemoveCVRef = absl::remove_cv_t<absl::remove_reference_t<T>>;
-
 }  // namespace promise_detail
 }  // namespace grpc_core
 
