@@ -67,9 +67,8 @@ class Latch {
     has_had_waiters_ = true;
 #endif
     return [this]() -> Poll<T> {
-      if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-        LOG(INFO) << DebugTag() << "Wait " << StateString();
-      }
+      GRPC_TRACE_LOG(promise_primitives, INFO)
+          << DebugTag() << "Wait " << StateString();
       if (has_value_) {
         return std::move(value_);
       } else {
@@ -85,9 +84,8 @@ class Latch {
     has_had_waiters_ = true;
 #endif
     return [this]() -> Poll<T> {
-      if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-        LOG(INFO) << DebugTag() << "WaitAndCopy " << StateString();
-      }
+      GRPC_TRACE_LOG(promise_primitives, INFO)
+          << DebugTag() << "WaitAndCopy " << StateString();
       if (has_value_) {
         return value_;
       } else {
@@ -98,9 +96,8 @@ class Latch {
 
   // Set the value of the latch. Can only be called once.
   void Set(T value) {
-    if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-      LOG(INFO) << DebugTag() << "Set " << StateString();
-    }
+    GRPC_TRACE_LOG(promise_primitives, INFO)
+        << DebugTag() << "Set " << StateString();
     DCHECK(!has_value_);
     value_ = std::move(value);
     has_value_ = true;
@@ -161,9 +158,8 @@ class Latch<void> {
     has_had_waiters_ = true;
 #endif
     return [this]() -> Poll<Empty> {
-      if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-        LOG(INFO) << DebugTag() << "PollWait " << StateString();
-      }
+      GRPC_TRACE_LOG(promise_primitives, INFO)
+          << DebugTag() << "PollWait " << StateString();
       if (is_set_) {
         return Empty{};
       } else {
@@ -174,9 +170,8 @@ class Latch<void> {
 
   // Set the latch. Can only be called once.
   void Set() {
-    if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-      LOG(INFO) << DebugTag() << "Set " << StateString();
-    }
+    GRPC_TRACE_LOG(promise_primitives, INFO)
+        << DebugTag() << "Set " << StateString();
     DCHECK(!is_set_);
     is_set_ = true;
     waiter_.Wake();
@@ -223,9 +218,8 @@ class ExternallyObservableLatch<void> {
   // Produce a promise to wait for this latch.
   auto Wait() {
     return [this]() -> Poll<Empty> {
-      if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-        LOG(INFO) << DebugTag() << "PollWait " << StateString();
-      }
+      GRPC_TRACE_LOG(promise_primitives, INFO)
+          << DebugTag() << "PollWait " << StateString();
       if (IsSet()) {
         return Empty{};
       } else {
@@ -236,9 +230,8 @@ class ExternallyObservableLatch<void> {
 
   // Set the latch.
   void Set() {
-    if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-      LOG(INFO) << DebugTag() << "Set " << StateString();
-    }
+    GRPC_TRACE_LOG(promise_primitives, INFO)
+        << DebugTag() << "Set " << StateString();
     is_set_.store(true, std::memory_order_relaxed);
     waiter_.Wake();
   }
@@ -246,9 +239,8 @@ class ExternallyObservableLatch<void> {
   bool IsSet() const { return is_set_.load(std::memory_order_relaxed); }
 
   void Reset() {
-    if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-      LOG(INFO) << DebugTag() << "Reset " << StateString();
-    }
+    GRPC_TRACE_LOG(promise_primitives, INFO)
+        << DebugTag() << "Reset " << StateString();
     is_set_.store(false, std::memory_order_relaxed);
   }
 
