@@ -33,7 +33,6 @@
 #include <grpc/grpc_security.h>
 #include <grpc/support/alloc.h>
 #include <grpc/support/json.h>
-#include <grpc/support/log.h>
 #include <grpc/support/port_platform.h>
 #include <grpc/support/string_util.h>
 
@@ -47,22 +46,24 @@
 
 namespace grpc_core {
 
-RefCountedPtr<UrlExternalAccountCredentials>
-UrlExternalAccountCredentials::Create(Options options,
-                                      std::vector<std::string> scopes,
-                                      grpc_error_handle* error) {
+absl::StatusOr<RefCountedPtr<UrlExternalAccountCredentials>>
+UrlExternalAccountCredentials::Create(
+    Options options, std::vector<std::string> scopes,
+    std::shared_ptr<grpc_event_engine::experimental::EventEngine>
+        event_engine) {
+  grpc_error_handle error;
   auto creds = MakeRefCounted<UrlExternalAccountCredentials>(
-      std::move(options), std::move(scopes), error);
-  if (error->ok()) {
-    return creds;
-  } else {
-    return nullptr;
-  }
+      std::move(options), std::move(scopes), std::move(event_engine), &error);
+  if (!error.ok()) return error;
+  return creds;
 }
 
 UrlExternalAccountCredentials::UrlExternalAccountCredentials(
-    Options options, std::vector<std::string> scopes, grpc_error_handle* error)
-    : ExternalAccountCredentials(options, std::move(scopes)) {
+    Options options, std::vector<std::string> scopes,
+    std::shared_ptr<grpc_event_engine::experimental::EventEngine> event_engine,
+    grpc_error_handle* error)
+    : ExternalAccountCredentials(options, std::move(scopes),
+                                 std::move(event_engine)) {
   auto it = options.credential_source.object().find("url");
   if (it == options.credential_source.object().end()) {
     *error = GRPC_ERROR_CREATE("url field not present.");
@@ -131,114 +132,88 @@ UrlExternalAccountCredentials::UrlExternalAccountCredentials(
   }
 }
 
-void UrlExternalAccountCredentials::RetrieveSubjectToken(
-    HTTPRequestContext* ctx, const Options& /*options*/,
-    std::function<void(std::string, grpc_error_handle)> cb) {
-  if (ctx == nullptr) {
-    FinishRetrieveSubjectToken(
-        "",
-        GRPC_ERROR_CREATE(
-            "Missing HTTPRequestContext to start subject token retrieval."));
-    return;
-  }
+std::string UrlExternalAccountCredentials::debug_string() {
+  return absl::StrCat("UrlExternalAccountCredentials{Audience:", audience(),
+                      ")");
+}
+
+UniqueTypeName UrlExternalAccountCredentials::type() const {
+  static UniqueTypeName::Factory kFactory("UrlExternalAccountCredentials");
+  return kFactory.Create();
+}
+
+OrphanablePtr<ExternalAccountCredentials::FetchBody>
+UrlExternalAccountCredentials::RetrieveSubjectToken(
+    Timestamp deadline,
+    absl::AnyInvocable<void(absl::StatusOr<std::string>)> on_done) {
   auto url_for_request =
       URI::Create(url_.scheme(), url_.authority(), url_full_path_,
                   {} /* query params */, "" /* fragment */);
   if (!url_for_request.ok()) {
-    FinishRetrieveSubjectToken(
-        "", absl_status_to_grpc_error(url_for_request.status()));
-    return;
-  }
-  ctx_ = ctx;
-  cb_ = cb;
-  grpc_http_request request;
-  memset(&request, 0, sizeof(grpc_http_request));
-  request.path = gpr_strdup(url_full_path_.c_str());
-  grpc_http_header* headers = nullptr;
-  request.hdr_count = headers_.size();
-  headers = static_cast<grpc_http_header*>(
-      gpr_malloc(sizeof(grpc_http_header) * request.hdr_count));
-  int i = 0;
-  for (auto const& header : headers_) {
-    headers[i].key = gpr_strdup(header.first.c_str());
-    headers[i].value = gpr_strdup(header.second.c_str());
-    ++i;
-  }
-  request.hdrs = headers;
-  grpc_http_response_destroy(&ctx_->response);
-  ctx_->response = {};
-  GRPC_CLOSURE_INIT(&ctx_->closure, OnRetrieveSubjectToken, this, nullptr);
-  CHECK(http_request_ == nullptr);
-  RefCountedPtr<grpc_channel_credentials> http_request_creds;
-  if (url_.scheme() == "http") {
-    http_request_creds = RefCountedPtr<grpc_channel_credentials>(
-        grpc_insecure_credentials_create());
-  } else {
-    http_request_creds = CreateHttpRequestSSLCredentials();
-  }
-  http_request_ =
-      HttpRequest::Get(std::move(*url_for_request), nullptr /* channel args */,
-                       ctx_->pollent, &request, ctx_->deadline, &ctx_->closure,
-                       &ctx_->response, std::move(http_request_creds));
-  http_request_->Start();
-  grpc_http_request_destroy(&request);
-}
-
-void UrlExternalAccountCredentials::OnRetrieveSubjectToken(
-    void* arg, grpc_error_handle error) {
-  UrlExternalAccountCredentials* self =
-      static_cast<UrlExternalAccountCredentials*>(arg);
-  self->OnRetrieveSubjectTokenInternal(error);
-}
-
-void UrlExternalAccountCredentials::OnRetrieveSubjectTokenInternal(
-    grpc_error_handle error) {
-  http_request_.reset();
-  if (!error.ok()) {
-    FinishRetrieveSubjectToken("", error);
-    return;
-  }
-  absl::string_view response_body(ctx_->response.body,
-                                  ctx_->response.body_length);
-  if (format_type_ == "json") {
-    auto response_json = JsonParse(response_body);
-    if (!response_json.ok() || response_json->type() != Json::Type::kObject) {
-      FinishRetrieveSubjectToken(
-          "", GRPC_ERROR_CREATE(
-                  "The format of response is not a valid json object."));
-      return;
-    }
-    auto response_it =
-        response_json->object().find(format_subject_token_field_name_);
-    if (response_it == response_json->object().end()) {
-      FinishRetrieveSubjectToken(
-          "", GRPC_ERROR_CREATE("Subject token field not present."));
-      return;
-    }
-    if (response_it->second.type() != Json::Type::kString) {
-      FinishRetrieveSubjectToken(
-          "", GRPC_ERROR_CREATE("Subject token field must be a string."));
-      return;
-    }
-    FinishRetrieveSubjectToken(response_it->second.string(), error);
-    return;
-  }
-  FinishRetrieveSubjectToken(std::string(response_body), absl::OkStatus());
-}
-
-void UrlExternalAccountCredentials::FinishRetrieveSubjectToken(
-    std::string subject_token, grpc_error_handle error) {
-  // Reset context
-  ctx_ = nullptr;
-  // Move object state into local variables.
-  auto cb = cb_;
-  cb_ = nullptr;
-  // Invoke the callback.
-  if (!error.ok()) {
-    cb("", error);
-  } else {
-    cb(subject_token, absl::OkStatus());
+    return MakeOrphanable<NoOpFetchBody>(
+        event_engine(), std::move(on_done),
+        absl_status_to_grpc_error(url_for_request.status()));
   }
+  return MakeOrphanable<HttpFetchBody>(
+      [&](grpc_http_response* response, grpc_closure* on_http_response) {
+        grpc_http_request request;
+        memset(&request, 0, sizeof(grpc_http_request));
+        request.path = gpr_strdup(url_full_path_.c_str());
+        grpc_http_header* headers = nullptr;
+        request.hdr_count = headers_.size();
+        headers = static_cast<grpc_http_header*>(
+            gpr_malloc(sizeof(grpc_http_header) * request.hdr_count));
+        int i = 0;
+        for (auto const& header : headers_) {
+          headers[i].key = gpr_strdup(header.first.c_str());
+          headers[i].value = gpr_strdup(header.second.c_str());
+          ++i;
+        }
+        request.hdrs = headers;
+        RefCountedPtr<grpc_channel_credentials> http_request_creds;
+        if (url_.scheme() == "http") {
+          http_request_creds = RefCountedPtr<grpc_channel_credentials>(
+              grpc_insecure_credentials_create());
+        } else {
+          http_request_creds = CreateHttpRequestSSLCredentials();
+        }
+        auto http_request =
+            HttpRequest::Get(std::move(*url_for_request), /*args=*/nullptr,
+                             pollent(), &request, deadline, on_http_response,
+                             response, std::move(http_request_creds));
+        http_request->Start();
+        grpc_http_request_destroy(&request);
+        return http_request;
+      },
+      [this, on_done = std::move(on_done)](
+          absl::StatusOr<std::string> response_body) mutable {
+        if (!response_body.ok()) {
+          on_done(std::move(response_body));
+          return;
+        }
+        if (format_type_ == "json") {
+          auto response_json = JsonParse(*response_body);
+          if (!response_json.ok() ||
+              response_json->type() != Json::Type::kObject) {
+            on_done(GRPC_ERROR_CREATE(
+                "The format of response is not a valid json object."));
+            return;
+          }
+          auto response_it =
+              response_json->object().find(format_subject_token_field_name_);
+          if (response_it == response_json->object().end()) {
+            on_done(GRPC_ERROR_CREATE("Subject token field not present."));
+            return;
+          }
+          if (response_it->second.type() != Json::Type::kString) {
+            on_done(GRPC_ERROR_CREATE("Subject token field must be a string."));
+            return;
+          }
+          on_done(response_it->second.string());
+          return;
+        }
+        on_done(std::move(response_body));
+      });
 }
 
 absl::string_view UrlExternalAccountCredentials::CredentialSourceType() {
