@@ -121,10 +121,9 @@ void grpc_plugin_credentials::PendingRequest::RequestMetadataReady(
                               GRPC_EXEC_CTX_FLAG_THREAD_RESOURCE_LOOP);
   grpc_core::RefCountedPtr<grpc_plugin_credentials::PendingRequest> r(
       static_cast<grpc_plugin_credentials::PendingRequest*>(request));
-  if (GRPC_TRACE_FLAG_ENABLED(plugin_credentials)) {
-    LOG(INFO) << "plugin_credentials[" << r->creds() << "]: request " << r.get()
-              << ": plugin returned asynchronously";
-  }
+  GRPC_TRACE_LOG(plugin_credentials, INFO)
+      << "plugin_credentials[" << r->creds() << "]: request " << r.get()
+      << ": plugin returned asynchronously";
   for (size_t i = 0; i < num_md; ++i) {
     grpc_metadata p;
     p.key = grpc_core::CSliceRef(md[i].key);
@@ -150,10 +149,9 @@ grpc_plugin_credentials::GetRequestMetadata(
       RefAsSubclass<grpc_plugin_credentials>(), std::move(initial_metadata),
       args);
   // Invoke the plugin.  The callback holds a ref to us.
-  if (GRPC_TRACE_FLAG_ENABLED(plugin_credentials)) {
-    LOG(INFO) << "plugin_credentials[" << this << "]: request " << request.get()
-              << ": invoking plugin";
-  }
+  GRPC_TRACE_LOG(plugin_credentials, INFO)
+      << "plugin_credentials[" << this << "]: request " << request.get()
+      << ": invoking plugin";
   grpc_metadata creds_md[GRPC_METADATA_CREDENTIALS_PLUGIN_SYNC_MAX];
   size_t num_creds_md = 0;
   grpc_status_code status = GRPC_STATUS_OK;
@@ -168,17 +166,15 @@ grpc_plugin_credentials::GetRequestMetadata(
                             child_request.get(), creds_md, &num_creds_md,
                             &status, &error_details)) {
     child_request.release();
-    if (GRPC_TRACE_FLAG_ENABLED(plugin_credentials)) {
-      LOG(INFO) << "plugin_credentials[" << this << "]: request "
-                << request.get() << ": plugin will return asynchronously";
-    }
+    GRPC_TRACE_LOG(plugin_credentials, INFO)
+        << "plugin_credentials[" << this << "]: request " << request.get()
+        << ": plugin will return asynchronously";
     return [request] { return request->PollAsyncResult(); };
   }
   // Synchronous return.
-  if (GRPC_TRACE_FLAG_ENABLED(plugin_credentials)) {
-    LOG(INFO) << "plugin_credentials[" << this << "]: request " << request.get()
-              << ": plugin returned synchronously";
-  }
+  GRPC_TRACE_LOG(plugin_credentials, INFO)
+      << "plugin_credentials[" << this << "]: request " << request.get()
+      << ": plugin returned synchronously";
   auto result = request->ProcessPluginResult(creds_md, num_creds_md, status,
                                              error_details);
   // Clean up.
