@@ -33,7 +33,6 @@
 #include "absl/strings/str_format.h"
 
 #include <grpc/support/alloc.h>
-#include <grpc/support/log.h>
 #include <grpc/support/log_windows.h>
 #include <grpc/support/string_util.h>
 #include <grpc/support/time.h>
@@ -73,7 +72,7 @@ namespace {
 // instantiated at the top of the virtual socket function callstack.
 class WSAErrorContext final {
  public:
-  explicit WSAErrorContext(){};
+  explicit WSAErrorContext() {};
 
   ~WSAErrorContext() {
     if (error_ != 0) {
@@ -133,8 +132,9 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
   }
 
   ~GrpcPolledFdWindows() override {
-    GRPC_CARES_TRACE_LOG("fd:|%s| ~GrpcPolledFdWindows shutdown_called_: %d ",
-                         GetName(), shutdown_called_);
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:|" << GetName()
+        << "| ~GrpcPolledFdWindows shutdown_called_: " << shutdown_called_;
     CSliceUnref(read_buf_);
     CSliceUnref(write_buf_);
     CHECK_EQ(read_closure_, nullptr);
@@ -173,10 +173,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
   }
 
   void ContinueRegisterForOnReadableLocked() {
-    GRPC_CARES_TRACE_LOG(
-        "fd:|%s| ContinueRegisterForOnReadableLocked "
-        "wsa_connect_error_:%d",
-        GetName(), wsa_connect_error_);
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:|" << GetName()
+        << "| ContinueRegisterForOnReadableLocked "
+        << "wsa_connect_error_:" << wsa_connect_error_;
     CHECK(connect_done_);
     if (wsa_connect_error_ != 0) {
       ScheduleAndNullReadClosure(GRPC_WSA_ERROR(wsa_connect_error_, "connect"));
@@ -194,10 +194,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
                     &winsocket_->read_info.overlapped, nullptr)) {
       int wsa_last_error = WSAGetLastError();
       char* msg = gpr_format_message(wsa_last_error);
-      GRPC_CARES_TRACE_LOG(
-          "fd:|%s| RegisterForOnReadableLocked WSARecvFrom error code:|%d| "
-          "msg:|%s|",
-          GetName(), wsa_last_error, msg);
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) fd:|" << GetName()
+          << "| RegisterForOnReadableLocked WSARecvFrom error code:|"
+          << wsa_last_error << "| msg:|" << msg << "|";
       gpr_free(msg);
       if (wsa_last_error != WSA_IO_PENDING) {
         ScheduleAndNullReadClosure(
@@ -210,14 +210,15 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
 
   void RegisterForOnWriteableLocked(grpc_closure* write_closure) override {
     if (socket_type_ == SOCK_DGRAM) {
-      GRPC_CARES_TRACE_LOG("fd:|%s| RegisterForOnWriteableLocked called",
-                           GetName());
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) fd:|" << GetName()
+          << "| RegisterForOnWriteableLocked called";
     } else {
       CHECK(socket_type_ == SOCK_STREAM);
-      GRPC_CARES_TRACE_LOG(
-          "fd:|%s| RegisterForOnWriteableLocked called tcp_write_state_: %d "
-          "connect_done_: %d",
-          GetName(), tcp_write_state_, connect_done_);
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) fd:|" << GetName()
+          << "| RegisterForOnWriteableLocked called tcp_write_state_: "
+          << tcp_write_state_ << " connect_done_: " << connect_done_;
     }
     CHECK_EQ(write_closure_, nullptr);
     write_closure_ = write_closure;
@@ -234,10 +235,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
   }
 
   void ContinueRegisterForOnWriteableLocked() {
-    GRPC_CARES_TRACE_LOG(
-        "fd:|%s| ContinueRegisterForOnWriteableLocked "
-        "wsa_connect_error_:%d",
-        GetName(), wsa_connect_error_);
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:|" << GetName()
+        << "| ContinueRegisterForOnWriteableLocked "
+        << "wsa_connect_error_:" << wsa_connect_error_;
     CHECK(connect_done_);
     if (wsa_connect_error_ != 0) {
       ScheduleAndNullWriteClosure(
@@ -288,10 +289,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
   ares_ssize_t RecvFrom(WSAErrorContext* wsa_error_ctx, void* data,
                         ares_socket_t data_len, int /* flags */,
                         struct sockaddr* from, ares_socklen_t* from_len) {
-    GRPC_CARES_TRACE_LOG(
-        "fd:|%s| RecvFrom called read_buf_has_data:%d Current read buf "
-        "length:|%d|",
-        GetName(), read_buf_has_data_, GRPC_SLICE_LENGTH(read_buf_));
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << GetName()
+        << " RecvFrom called read_buf_has_data:" << read_buf_has_data_
+        << " Current read buf length:" << GRPC_SLICE_LENGTH(read_buf_);
     if (!read_buf_has_data_) {
       wsa_error_ctx->SetWSAError(WSAEWOULDBLOCK);
       return -1;
@@ -340,20 +341,21 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
     int out = WSASend(grpc_winsocket_wrapped_socket(winsocket_), &buf, 1,
                       bytes_sent_ptr, flags, overlapped, nullptr);
     *wsa_error_code = WSAGetLastError();
-    GRPC_CARES_TRACE_LOG(
-        "fd:|%s| SendWriteBuf WSASend buf.len:%d *bytes_sent_ptr:%d "
-        "overlapped:%p "
-        "return:%d *wsa_error_code:%d",
-        GetName(), buf.len, bytes_sent_ptr != nullptr ? *bytes_sent_ptr : 0,
-        overlapped, out, *wsa_error_code);
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << GetName()
+        << " SendWriteBuf WSASend buf.len:" << buf.len << " *bytes_sent_ptr:"
+        << (bytes_sent_ptr != nullptr ? *bytes_sent_ptr : 0)
+        << " overlapped:" << overlapped << " return:" << out
+        << " *wsa_error_code:" << *wsa_error_code;
     return out;
   }
 
   ares_ssize_t SendV(WSAErrorContext* wsa_error_ctx, const struct iovec* iov,
                      int iov_count) {
-    GRPC_CARES_TRACE_LOG(
-        "fd:|%s| SendV called connect_done_:%d wsa_connect_error_:%d",
-        GetName(), connect_done_, wsa_connect_error_);
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << GetName()
+        << " SendV called connect_done_:" << connect_done_
+        << " wsa_connect_error_:" << wsa_connect_error_;
     if (!connect_done_) {
       wsa_error_ctx->SetWSAError(WSAEWOULDBLOCK);
       return -1;
@@ -377,7 +379,8 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
     // c-ares doesn't handle retryable errors on writes of UDP sockets.
     // Therefore, the sendv handler for UDP sockets must only attempt
     // to write everything inline.
-    GRPC_CARES_TRACE_LOG("fd:|%s| SendVUDP called", GetName());
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << GetName() << " SendVUDP called";
     CHECK_EQ(GRPC_SLICE_LENGTH(write_buf_), 0);
     CSliceUnref(write_buf_);
     write_buf_ = FlattenIovec(iov, iov_count);
@@ -388,9 +391,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
       write_buf_ = grpc_empty_slice();
       wsa_error_ctx->SetWSAError(wsa_error_code);
       char* msg = gpr_format_message(wsa_error_code);
-      GRPC_CARES_TRACE_LOG(
-          "fd:|%s| SendVUDP SendWriteBuf error code:%d msg:|%s|", GetName(),
-          wsa_error_code, msg);
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) fd:" << GetName()
+          << " SendVUDP SendWriteBuf error code:" << wsa_error_code
+          << " msg:" << msg;
       gpr_free(msg);
       return -1;
     }
@@ -406,8 +410,9 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
     // out in the background, and making further send progress in general, will
     // happen as long as c-ares continues to show interest in writeability on
     // this fd.
-    GRPC_CARES_TRACE_LOG("fd:|%s| SendVTCP called tcp_write_state_:%d",
-                         GetName(), tcp_write_state_);
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << GetName()
+        << " SendVTCP called tcp_write_state_:" << tcp_write_state_;
     switch (tcp_write_state_) {
       case WRITE_IDLE:
         tcp_write_state_ = WRITE_REQUESTED;
@@ -450,13 +455,13 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
   }
 
   void OnTcpConnectLocked(grpc_error_handle error) {
-    GRPC_CARES_TRACE_LOG(
-        "fd:%s InnerOnTcpConnectLocked error:|%s| "
-        "pending_register_for_readable:%d"
-        " pending_register_for_writeable:%d",
-        GetName(), StatusToString(error).c_str(),
-        pending_continue_register_for_on_readable_locked_,
-        pending_continue_register_for_on_writeable_locked_);
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << GetName()
+        << " InnerOnTcpConnectLocked error:" << StatusToString(error)
+        << " pending_register_for_readable:"
+        << pending_continue_register_for_on_readable_locked_
+        << " pending_register_for_writeable:"
+        << pending_continue_register_for_on_writeable_locked_;
     CHECK(!connect_done_);
     connect_done_ = true;
     CHECK_EQ(wsa_connect_error_, 0);
@@ -473,10 +478,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
       if (!wsa_success) {
         wsa_connect_error_ = WSAGetLastError();
         char* msg = gpr_format_message(wsa_connect_error_);
-        GRPC_CARES_TRACE_LOG(
-            "fd:%s InnerOnTcpConnectLocked WSA overlapped result code:%d "
-            "msg:|%s|",
-            GetName(), wsa_connect_error_, msg);
+        GRPC_TRACE_VLOG(cares_resolver, 2)
+            << "(c-ares resolver) fd:" << GetName()
+            << " InnerOnTcpConnectLocked WSA overlapped result code:"
+            << wsa_connect_error_ << " msg:" << msg;
         gpr_free(msg);
       }
     }
@@ -502,7 +507,8 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
 
   int ConnectUDP(WSAErrorContext* wsa_error_ctx, const struct sockaddr* target,
                  ares_socklen_t target_len) {
-    GRPC_CARES_TRACE_LOG("fd:%s ConnectUDP", GetName());
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << GetName() << " ConnectUDP";
     CHECK(!connect_done_);
     CHECK_EQ(wsa_connect_error_, 0);
     SOCKET s = grpc_winsocket_wrapped_socket(winsocket_);
@@ -512,8 +518,9 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
     wsa_error_ctx->SetWSAError(wsa_connect_error_);
     connect_done_ = true;
     char* msg = gpr_format_message(wsa_connect_error_);
-    GRPC_CARES_TRACE_LOG("fd:%s WSAConnect error code:|%d| msg:|%s|", GetName(),
-                         wsa_connect_error_, msg);
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << GetName() << " WSAConnect error code:|"
+        << wsa_connect_error_ << "| msg:|" << msg << "|";
     gpr_free(msg);
     // c-ares expects a posix-style connect API
     return out == 0 ? 0 : -1;
@@ -521,7 +528,8 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
 
   int ConnectTCP(WSAErrorContext* wsa_error_ctx, const struct sockaddr* target,
                  ares_socklen_t target_len) {
-    GRPC_CARES_TRACE_LOG("fd:%s ConnectTCP", GetName());
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << GetName() << " ConnectTCP";
     LPFN_CONNECTEX ConnectEx;
     GUID guid = WSAID_CONNECTEX;
     DWORD ioctl_num_bytes;
@@ -532,10 +540,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
       int wsa_last_error = WSAGetLastError();
       wsa_error_ctx->SetWSAError(wsa_last_error);
       char* msg = gpr_format_message(wsa_last_error);
-      GRPC_CARES_TRACE_LOG(
-          "fd:%s WSAIoctl(SIO_GET_EXTENSION_FUNCTION_POINTER) error code:%d "
-          "msg:|%s|",
-          GetName(), wsa_last_error, msg);
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) fd:" << GetName()
+          << " WSAIoctl(SIO_GET_EXTENSION_FUNCTION_POINTER) error code:"
+          << wsa_last_error << " msg:|" << msg << "|";
       gpr_free(msg);
       connect_done_ = true;
       wsa_connect_error_ = wsa_last_error;
@@ -555,8 +563,9 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
       int wsa_last_error = WSAGetLastError();
       wsa_error_ctx->SetWSAError(wsa_last_error);
       char* msg = gpr_format_message(wsa_last_error);
-      GRPC_CARES_TRACE_LOG("fd:%s bind error code:%d msg:|%s|", GetName(),
-                           wsa_last_error, msg);
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) fd:" << GetName()
+          << " bind error code:" << wsa_last_error << " msg:|" << msg << "|";
       gpr_free(msg);
       connect_done_ = true;
       wsa_connect_error_ = wsa_last_error;
@@ -569,8 +578,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
       int wsa_last_error = WSAGetLastError();
       wsa_error_ctx->SetWSAError(wsa_last_error);
       char* msg = gpr_format_message(wsa_last_error);
-      GRPC_CARES_TRACE_LOG("fd:%s ConnectEx error code:%d msg:|%s|", GetName(),
-                           wsa_last_error, msg);
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) fd:" << GetName()
+          << " ConnectEx error code:" << wsa_last_error << " msg:|" << msg
+          << "|";
       gpr_free(msg);
       if (wsa_last_error == WSA_IO_PENDING) {
         // c-ares only understands WSAEINPROGRESS and EWOULDBLOCK error codes on
@@ -610,11 +621,12 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
         if (winsocket_->read_info.wsa_error != WSAEMSGSIZE) {
           error = GRPC_WSA_ERROR(winsocket_->read_info.wsa_error,
                                  "OnIocpReadableInner");
-          GRPC_CARES_TRACE_LOG(
-              "fd:|%s| OnIocpReadableInner winsocket_->read_info.wsa_error "
-              "code:|%d| msg:|%s|",
-              GetName(), winsocket_->read_info.wsa_error,
-              StatusToString(error).c_str());
+          GRPC_TRACE_VLOG(cares_resolver, 2)
+              << "(c-ares resolver) fd:|" << GetName()
+              << "| OnIocpReadableInner winsocket_->read_info.wsa_error "
+                 "code:|"
+              << winsocket_->read_info.wsa_error << "| msg:|"
+              << StatusToString(error) << "|";
         }
       }
     }
@@ -626,9 +638,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
       CSliceUnref(read_buf_);
       read_buf_ = grpc_empty_slice();
     }
-    GRPC_CARES_TRACE_LOG(
-        "fd:|%s| OnIocpReadable finishing. read buf length now:|%d|", GetName(),
-        GRPC_SLICE_LENGTH(read_buf_));
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:|" << GetName()
+        << "| OnIocpReadable finishing. read buf length now:|"
+        << GRPC_SLICE_LENGTH(read_buf_) << "|";
     ScheduleAndNullReadClosure(error);
   }
 
@@ -639,17 +652,19 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
   }
 
   void OnIocpWriteableLocked(grpc_error_handle error) {
-    GRPC_CARES_TRACE_LOG("OnIocpWriteableInner. fd:|%s|", GetName());
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) OnIocpWriteableInner. fd:|" << GetName() << "|";
     CHECK(socket_type_ == SOCK_STREAM);
     if (error.ok()) {
       if (winsocket_->write_info.wsa_error != 0) {
         error = GRPC_WSA_ERROR(winsocket_->write_info.wsa_error,
                                "OnIocpWriteableInner");
-        GRPC_CARES_TRACE_LOG(
-            "fd:|%s| OnIocpWriteableInner. winsocket_->write_info.wsa_error "
-            "code:|%d| msg:|%s|",
-            GetName(), winsocket_->write_info.wsa_error,
-            StatusToString(error).c_str());
+        GRPC_TRACE_VLOG(cares_resolver, 2)
+            << "(c-ares resolver) fd:|" << GetName()
+            << "| OnIocpWriteableInner. winsocket_->write_info.wsa_error "
+               "code:|"
+            << winsocket_->write_info.wsa_error << "| msg:|"
+            << StatusToString(error) << "|";
       }
     }
     CHECK(tcp_write_state_ == WRITE_PENDING);
@@ -657,8 +672,10 @@ class GrpcPolledFdWindows final : public GrpcPolledFd {
       tcp_write_state_ = WRITE_WAITING_FOR_VERIFICATION_UPON_RETRY;
       write_buf_ = grpc_slice_sub_no_ref(
           write_buf_, 0, winsocket_->write_info.bytes_transferred);
-      GRPC_CARES_TRACE_LOG("fd:|%s| OnIocpWriteableInner. bytes transferred:%d",
-                           GetName(), winsocket_->write_info.bytes_transferred);
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) fd:|" << GetName()
+          << "| OnIocpWriteableInner. bytes transferred:"
+          << winsocket_->write_info.bytes_transferred;
     } else {
       CSliceUnref(write_buf_);
       write_buf_ = grpc_empty_slice();
@@ -728,7 +745,9 @@ class GrpcPolledFdFactoryWindows final : public GrpcPolledFdFactory {
   //
   static ares_socket_t Socket(int af, int type, int protocol, void* user_data) {
     if (type != SOCK_DGRAM && type != SOCK_STREAM) {
-      GRPC_CARES_TRACE_LOG("Socket called with invalid socket type:%d", type);
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) Socket called with invalid socket type:"
+          << type;
       return INVALID_SOCKET;
     }
     GrpcPolledFdFactoryWindows* self =
@@ -736,15 +755,16 @@ class GrpcPolledFdFactoryWindows final : public GrpcPolledFdFactory {
     SOCKET s = WSASocket(af, type, protocol, nullptr, 0,
                          grpc_get_default_wsa_socket_flags());
     if (s == INVALID_SOCKET) {
-      GRPC_CARES_TRACE_LOG(
-          "WSASocket failed with params af:%d type:%d protocol:%d", af, type,
-          protocol);
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) WSASocket failed with params af:" << af
+          << " type:" << type << " protocol:" << protocol;
       return s;
     }
     grpc_error_handle error = grpc_tcp_set_non_block(s);
     if (!error.ok()) {
-      GRPC_CARES_TRACE_LOG("WSAIoctl failed with error: %s",
-                           StatusToString(error).c_str());
+      GRPC_TRACE_VLOG(cares_resolver, 2)
+          << "(c-ares resolver) WSAIoctl failed with error: "
+          << StatusToString(error);
       return INVALID_SOCKET;
     }
     auto on_shutdown_locked = [self, s]() {
@@ -755,9 +775,10 @@ class GrpcPolledFdFactoryWindows final : public GrpcPolledFdFactory {
     };
     auto polled_fd = new GrpcPolledFdWindows(s, self->mu_, af, type,
                                              std::move(on_shutdown_locked));
-    GRPC_CARES_TRACE_LOG(
-        "fd:|%s| created with params af:%d type:%d protocol:%d",
-        polled_fd->GetName(), af, type, protocol);
+    GRPC_TRACE_VLOG(cares_resolver, 2)
+        << "(c-ares resolver) fd:" << polled_fd->GetName()
+        << " created with params af:" << af << " type:" << type
+        << " protocol:" << protocol;
     CHECK(self->sockets_.insert({s, polled_fd}).second);
     return s;
   }
