@@ -90,15 +90,11 @@ NativeClientChannelDNSResolver::NativeClientChannelDNSResolver(
                           .set_max_backoff(Duration::Milliseconds(
                               GRPC_DNS_RECONNECT_MAX_BACKOFF_SECONDS * 1000)),
                       &dns_resolver_trace) {
-  if (GRPC_TRACE_FLAG_ENABLED(dns_resolver)) {
-    VLOG(2) << "[dns_resolver=" << this << "] created";
-  }
+  GRPC_TRACE_VLOG(dns_resolver, 2) << "[dns_resolver=" << this << "] created";
 }
 
 NativeClientChannelDNSResolver::~NativeClientChannelDNSResolver() {
-  if (GRPC_TRACE_FLAG_ENABLED(dns_resolver)) {
-    VLOG(2) << "[dns_resolver=" << this << "] destroyed";
-  }
+  GRPC_TRACE_VLOG(dns_resolver, 2) << "[dns_resolver=" << this << "] destroyed";
 }
 
 OrphanablePtr<Orphanable> NativeClientChannelDNSResolver::StartRequest() {
@@ -107,19 +103,17 @@ OrphanablePtr<Orphanable> NativeClientChannelDNSResolver::StartRequest() {
       absl::bind_front(&NativeClientChannelDNSResolver::OnResolved, this),
       name_to_resolve(), kDefaultSecurePort, kDefaultDNSRequestTimeout,
       interested_parties(), /*name_server=*/"");
-  if (GRPC_TRACE_FLAG_ENABLED(dns_resolver)) {
-    VLOG(2) << "[dns_resolver=" << this << "] starting request="
-            << DNSResolver::HandleToString(dns_request_handle);
-  }
+  GRPC_TRACE_VLOG(dns_resolver, 2)
+      << "[dns_resolver=" << this << "] starting request="
+      << DNSResolver::HandleToString(dns_request_handle);
   return MakeOrphanable<Request>();
 }
 
 void NativeClientChannelDNSResolver::OnResolved(
     absl::StatusOr<std::vector<grpc_resolved_address>> addresses_or) {
-  if (GRPC_TRACE_FLAG_ENABLED(dns_resolver)) {
-    VLOG(2) << "[dns_resolver=" << this
-            << "] request complete, status=" << addresses_or.status();
-  }
+  GRPC_TRACE_VLOG(dns_resolver, 2)
+      << "[dns_resolver=" << this
+      << "] request complete, status=" << addresses_or.status();
   // Convert result from iomgr DNS API into Resolver::Result.
   Result result;
   if (addresses_or.ok()) {
