@@ -198,11 +198,10 @@ absl::StatusOr<std::string> GetBootstrapContents(const char* fallback_config) {
   // First, try GRPC_XDS_BOOTSTRAP env var.
   auto path = GetEnv("GRPC_XDS_BOOTSTRAP");
   if (path.has_value()) {
-    if (GRPC_TRACE_FLAG_ENABLED(xds_client)) {
-      LOG(INFO) << "Got bootstrap file location from GRPC_XDS_BOOTSTRAP "
-                   "environment variable: "
-                << *path;
-    }
+    GRPC_TRACE_LOG(xds_client, INFO)
+        << "Got bootstrap file location from GRPC_XDS_BOOTSTRAP "
+           "environment variable: "
+        << *path;
     auto contents = LoadFile(*path, /*add_null_terminator=*/true);
     if (!contents.ok()) return contents.status();
     return std::string(contents->as_string_view());
@@ -210,10 +209,9 @@ absl::StatusOr<std::string> GetBootstrapContents(const char* fallback_config) {
   // Next, try GRPC_XDS_BOOTSTRAP_CONFIG env var.
   auto env_config = GetEnv("GRPC_XDS_BOOTSTRAP_CONFIG");
   if (env_config.has_value()) {
-    if (GRPC_TRACE_FLAG_ENABLED(xds_client)) {
-      LOG(INFO) << "Got bootstrap contents from GRPC_XDS_BOOTSTRAP_CONFIG "
-                   "environment variable";
-    }
+    GRPC_TRACE_LOG(xds_client, INFO)
+        << "Got bootstrap contents from GRPC_XDS_BOOTSTRAP_CONFIG "
+        << "environment variable";
     return std::move(*env_config);
   }
   // Finally, try fallback config.
@@ -258,9 +256,8 @@ absl::StatusOr<RefCountedPtr<GrpcXdsClient>> GrpcXdsClient::GetOrCreate(
   // Find bootstrap contents.
   auto bootstrap_contents = GetBootstrapContents(g_fallback_bootstrap_config);
   if (!bootstrap_contents.ok()) return bootstrap_contents.status();
-  if (GRPC_TRACE_FLAG_ENABLED(xds_client)) {
-    LOG(INFO) << "xDS bootstrap contents: " << *bootstrap_contents;
-  }
+  GRPC_TRACE_LOG(xds_client, INFO)
+      << "xDS bootstrap contents: " << *bootstrap_contents;
   // Parse bootstrap.
   auto bootstrap = GrpcXdsBootstrap::Create(*bootstrap_contents);
   if (!bootstrap.ok()) return bootstrap.status();
@@ -270,10 +267,8 @@ absl::StatusOr<RefCountedPtr<GrpcXdsClient>> GrpcXdsClient::GetOrCreate(
       key, std::move(*bootstrap), channel_args,
       MakeOrphanable<GrpcXdsTransportFactory>(channel_args));
   g_xds_client_map->emplace(xds_client->key(), xds_client.get());
-  if (GRPC_TRACE_FLAG_ENABLED(xds_client)) {
-    LOG(INFO) << "[xds_client " << xds_client.get()
-              << "] Created xDS client for key " << key;
-  }
+  GRPC_TRACE_LOG(xds_client, INFO) << "[xds_client " << xds_client.get()
+                                   << "] Created xDS client for key " << key;
   return xds_client;
 }
 
