@@ -53,6 +53,7 @@
 #include "src/core/util/upb_utils.h"
 #include "src/core/xds/grpc/xds_audit_logger_registry.h"
 #include "src/core/xds/grpc/xds_bootstrap_grpc.h"
+#include "src/core/xds/grpc/xds_common_types_parser.h"
 #include "src/core/xds/xds_client/xds_client.h"
 
 namespace grpc_core {
@@ -190,11 +191,10 @@ Json ParseCidrRangeToJson(const envoy_config_core_v3_CidrRange* range) {
   json.emplace("addressPrefix",
                Json::FromString(UpbStringToStdString(
                    envoy_config_core_v3_CidrRange_address_prefix(range))));
-  const auto* prefix_len = envoy_config_core_v3_CidrRange_prefix_len(range);
-  if (prefix_len != nullptr) {
-    json.emplace(
-        "prefixLen",
-        Json::FromNumber(google_protobuf_UInt32Value_value(prefix_len)));
+  auto prefix_len =
+      ParseUInt32Value(envoy_config_core_v3_CidrRange_prefix_len(range));
+  if (prefix_len.has_value()) {
+    json.emplace("prefixLen", Json::FromNumber(*prefix_len));
   }
   return Json::FromObject(std::move(json));
 }
@@ -515,6 +515,7 @@ void XdsHttpRbacFilter::PopulateSymtab(upb_DefPool* symtab) const {
 
 absl::optional<XdsHttpFilterImpl::FilterConfig>
 XdsHttpRbacFilter::GenerateFilterConfig(
+    absl::string_view /*instance_name*/,
     const XdsResourceType::DecodeContext& context, XdsExtension extension,
     ValidationErrors* errors) const {
   absl::string_view* serialized_filter_config =
@@ -536,6 +537,7 @@ XdsHttpRbacFilter::GenerateFilterConfig(
 
 absl::optional<XdsHttpFilterImpl::FilterConfig>
 XdsHttpRbacFilter::GenerateFilterConfigOverride(
+    absl::string_view /*instance_name*/,
     const XdsResourceType::DecodeContext& context, XdsExtension extension,
     ValidationErrors* errors) const {
   absl::string_view* serialized_filter_config =
@@ -578,7 +580,7 @@ ChannelArgs XdsHttpRbacFilter::ModifyChannelArgs(
 }
 
 absl::StatusOr<XdsHttpFilterImpl::ServiceConfigJsonEntry>
-XdsHttpRbacFilter::GenerateServiceConfig(
+XdsHttpRbacFilter::GenerateMethodConfig(
     const FilterConfig& hcm_filter_config,
     const FilterConfig* filter_config_override) const {
   const Json& policy_json = filter_config_override != nullptr
@@ -588,4 +590,10 @@ XdsHttpRbacFilter::GenerateServiceConfig(
   return ServiceConfigJsonEntry{"rbacPolicy", JsonDump(policy_json)};
 }
 
+absl::StatusOr<XdsHttpFilterImpl::ServiceConfigJsonEntry>
+XdsHttpRbacFilter::GenerateServiceConfig(
+    const FilterConfig& /*hcm_filter_config*/) const {
+  return ServiceConfigJsonEntry{"", ""};
+}
+
 }  // namespace grpc_core
