@@ -441,7 +441,7 @@ XdsRouteConfigResource::TypedPerFilterConfig ParseTypedPerFilterConfig(
     }
     absl::optional<XdsHttpFilterImpl::FilterConfig> filter_config =
         filter_impl->GenerateFilterConfigOverride(
-            context, std::move(*extension_to_use), errors);
+            key, context, std::move(*extension_to_use), errors);
     if (filter_config.has_value()) {
       typed_per_filter_config[std::string(key)] = std::move(*filter_config);
     }
@@ -474,18 +474,13 @@ XdsRouteConfigResource::RetryPolicy RetryPolicyParse(
       }
     }
   }
-  const google_protobuf_UInt32Value* num_retries =
-      envoy_config_route_v3_RetryPolicy_num_retries(retry_policy_proto);
-  if (num_retries != nullptr) {
-    uint32_t num_retries_value = google_protobuf_UInt32Value_value(num_retries);
-    if (num_retries_value == 0) {
-      ValidationErrors::ScopedField field(errors, ".num_retries");
-      errors->AddError("must be greater than 0");
-    } else {
-      retry_policy.num_retries = num_retries_value;
-    }
-  } else {
-    retry_policy.num_retries = 1;
+  retry_policy.num_retries =
+      ParseUInt32Value(
+          envoy_config_route_v3_RetryPolicy_num_retries(retry_policy_proto))
+          .value_or(1);
+  if (retry_policy.num_retries == 0) {
+    ValidationErrors::ScopedField field(errors, ".num_retries");
+    errors->AddError("must be greater than 0");
   }
   const envoy_config_route_v3_RetryPolicy_RetryBackOff* backoff =
       envoy_config_route_v3_RetryPolicy_retry_back_off(retry_policy_proto);
@@ -692,14 +687,14 @@ absl::optional<XdsRouteConfigResource::Route::RouteAction> RouteActionParse(
         errors->AddError("must be non-empty");
       }
       // weight
-      const google_protobuf_UInt32Value* weight_proto =
+      auto weight = ParseUInt32Value(
           envoy_config_route_v3_WeightedCluster_ClusterWeight_weight(
-              cluster_proto);
-      if (weight_proto == nullptr) {
+              cluster_proto));
+      if (!weight.has_value()) {
         ValidationErrors::ScopedField field(errors, ".weight");
         errors->AddError("field not present");
       } else {
-        cluster.weight = google_protobuf_UInt32Value_value(weight_proto);
+        cluster.weight = *weight;
         if (cluster.weight == 0) continue;
         total_weight += cluster.weight;
       }
