@@ -15,7 +15,7 @@
 import logging
 import threading
 import time
-from typing import Any, Dict, Iterable, List, Optional, Set, Union
+from typing import Any, AnyStr, Dict, Iterable, List, Optional, Set, Union
 
 import grpc
 
@@ -24,6 +24,8 @@ from grpc_observability import _cyobservability
 from grpc_observability import _observability
 from grpc_observability import _open_telemetry_measures
 from grpc_observability._cyobservability import MetricsName
+from grpc_observability._cyobservability import PLUGIN_IDENTIFIER_SEP
+from grpc_observability._observability import OptionalLabelType
 from grpc_observability._observability import StatsData
 from opentelemetry.metrics import Counter
 from opentelemetry.metrics import Histogram
@@ -37,9 +39,13 @@ ServerCallTracerFactoryCapsule = (
 )
 grpc_observability = Any  # grpc_observability.py imports this module.
 OpenTelemetryPlugin = Any  # _open_telemetry_plugin.py imports this module.
+OpenTelemetryPluginOption = (
+    Any  # _open_telemetry_plugin.py imports this module.
+)
 
 GRPC_METHOD_LABEL = "grpc.method"
 GRPC_TARGET_LABEL = "grpc.target"
+GRPC_CLIENT_METRIC_PREFIX = "grpc.client"
 GRPC_OTHER_LABEL_VALUE = "other"
 _observability_lock: threading.RLock = threading.RLock()
 _OPEN_TELEMETRY_OBSERVABILITY: Optional["OpenTelemetryObservability"] = None
@@ -68,10 +74,16 @@ GRPC_STATUS_CODE_TO_STRING = {
 class _OpenTelemetryPlugin:
     _plugin: OpenTelemetryPlugin
     _metric_to_recorder: Dict[MetricsName, Union[Counter, Histogram]]
+    _enabled_client_plugin_options: Optional[List[OpenTelemetryPluginOption]]
+    _enabled_server_plugin_options: Optional[List[OpenTelemetryPluginOption]]
+    identifier: str
 
     def __init__(self, plugin: OpenTelemetryPlugin):
         self._plugin = plugin
         self._metric_to_recorder = dict()
+        self.identifier = str(id(self))
+        self._enabled_client_plugin_options = None
+        self._enabled_server_plugin_options = None
 
         meter_provider = self._plugin.meter_provider
         if meter_provider:
@@ -87,16 +99,38 @@ class _OpenTelemetryPlugin:
 
     def _record_stats_data(self, stats_data: StatsData) -> None:
         recorder = self._metric_to_recorder[stats_data.name]
+        enabled_plugin_options = []
+        if GRPC_CLIENT_METRIC_PREFIX in recorder.name:
+            enabled_plugin_options = self._enabled_client_plugin_options
+        else:
+            enabled_plugin_options = self._enabled_server_plugin_options
+        # Only deserialize labels if we need add exchanged labels.
+        if stats_data.include_exchange_labels:
+            deserialized_labels = self._deserialize_labels(
+                stats_data.labels, enabled_plugin_options
+            )
+        else:
+            deserialized_labels = stats_data.labels
+        labels = self._maybe_add_labels(
+            stats_data.include_exchange_labels,
+            deserialized_labels,
+            enabled_plugin_options,
+        )
+        decoded_labels = self.decode_labels(labels)
 
-        target = stats_data.labels.get(GRPC_TARGET_LABEL, "")
+        target = decoded_labels.get(GRPC_TARGET_LABEL, "")
         if not self._plugin.target_attribute_filter(target):
             # Filter target name.
-            stats_data.labels[GRPC_TARGET_LABEL] = GRPC_OTHER_LABEL_VALUE
+            decoded_labels[GRPC_TARGET_LABEL] = GRPC_OTHER_LABEL_VALUE
 
-        method = stats_data.labels.get(GRPC_METHOD_LABEL, "")
-        if not self._plugin.generic_method_attribute_filter(method):
-            # Filter method name.
-            stats_data.labels[GRPC_METHOD_LABEL] = GRPC_OTHER_LABEL_VALUE
+        method = decoded_labels.get(GRPC_METHOD_LABEL, "")
+        if not (
+            stats_data.registered_method
+            or self._plugin.generic_method_attribute_filter(method)
+        ):
+            # Filter method name if it's not registered method and
+            # generic_method_attribute_filter returns false.
+            decoded_labels[GRPC_METHOD_LABEL] = GRPC_OTHER_LABEL_VALUE
 
         value = 0
         if stats_data.measure_double:
@@ -104,18 +138,109 @@ class _OpenTelemetryPlugin:
         else:
             value = stats_data.value_int
         if isinstance(recorder, Counter):
-            recorder.add(value, attributes=stats_data.labels)
+            recorder.add(value, attributes=decoded_labels)
         elif isinstance(recorder, Histogram):
-            recorder.record(value, attributes=stats_data.labels)
+            recorder.record(value, attributes=decoded_labels)
 
-    # pylint: disable=no-self-use
     def maybe_record_stats_data(self, stats_data: List[StatsData]) -> None:
         # Records stats data to MeterProvider.
         if self._should_record(stats_data):
             self._record_stats_data(stats_data)
 
+    def get_client_exchange_labels(self) -> Dict[str, AnyStr]:
+        """Get labels used for client side Metadata Exchange."""
+
+        labels_for_exchange = {}
+        for plugin_option in self._enabled_client_plugin_options:
+            if hasattr(plugin_option, "get_label_injector") and hasattr(
+                plugin_option.get_label_injector(), "get_labels_for_exchange"
+            ):
+                labels_for_exchange.update(
+                    plugin_option.get_label_injector().get_labels_for_exchange()
+                )
+        return labels_for_exchange
+
+    def get_server_exchange_labels(self) -> Dict[str, str]:
+        """Get labels used for server side Metadata Exchange."""
+        labels_for_exchange = {}
+        for plugin_option in self._enabled_server_plugin_options:
+            if hasattr(plugin_option, "get_label_injector") and hasattr(
+                plugin_option.get_label_injector(), "get_labels_for_exchange"
+            ):
+                labels_for_exchange.update(
+                    plugin_option.get_label_injector().get_labels_for_exchange()
+                )
+        return labels_for_exchange
+
+    def activate_client_plugin_options(self, target: bytes) -> None:
+        """Activate client plugin options based on option settings."""
+        target_str = target.decode("utf-8", "replace")
+        if not self._enabled_client_plugin_options:
+            self._enabled_client_plugin_options = []
+            for plugin_option in self._plugin.plugin_options:
+                if hasattr(
+                    plugin_option, "is_active_on_client_channel"
+                ) and plugin_option.is_active_on_client_channel(target_str):
+                    self._enabled_client_plugin_options.append(plugin_option)
+
+    def activate_server_plugin_options(self, xds: bool) -> None:
+        """Activate server plugin options based on option settings."""
+        if not self._enabled_server_plugin_options:
+            self._enabled_server_plugin_options = []
+            for plugin_option in self._plugin.plugin_options:
+                if hasattr(
+                    plugin_option, "is_active_on_server"
+                ) and plugin_option.is_active_on_server(xds):
+                    self._enabled_server_plugin_options.append(plugin_option)
+
+    @staticmethod
+    def _deserialize_labels(
+        labels: Dict[str, AnyStr],
+        enabled_plugin_options: List[OpenTelemetryPluginOption],
+    ) -> Dict[str, AnyStr]:
+        for plugin_option in enabled_plugin_options:
+            if all(
+                [
+                    hasattr(plugin_option, "get_label_injector"),
+                    hasattr(
+                        plugin_option.get_label_injector(), "deserialize_labels"
+                    ),
+                ]
+            ):
+                labels = plugin_option.get_label_injector().deserialize_labels(
+                    labels
+                )
+        return labels
+
+    @staticmethod
+    def _maybe_add_labels(
+        include_exchange_labels: bool,
+        labels: Dict[str, str],
+        enabled_plugin_options: List[OpenTelemetryPluginOption],
+    ) -> Dict[str, AnyStr]:
+        for plugin_option in enabled_plugin_options:
+            if all(
+                [
+                    hasattr(plugin_option, "get_label_injector"),
+                    hasattr(
+                        plugin_option.get_label_injector(),
+                        "get_additional_labels",
+                    ),
+                ]
+            ):
+                labels.update(
+                    plugin_option.get_label_injector().get_additional_labels(
+                        include_exchange_labels
+                    )
+                )
+        return labels
+
+    def get_enabled_optional_labels(self) -> List[OptionalLabelType]:
+        return self._plugin._get_enabled_optional_labels()
+
+    @staticmethod
     def _register_metrics(
-        self, meter: Meter, metrics: List[_open_telemetry_measures.Metric]
+        meter: Meter, metrics: List[_open_telemetry_measures.Metric]
     ) -> Dict[MetricsName, Union[Counter, Histogram]]:
         metric_to_recorder_map = {}
         recorder = None
@@ -179,6 +304,15 @@ class _OpenTelemetryPlugin:
             metric_to_recorder_map[metric.cyname] = recorder
         return metric_to_recorder_map
 
+    @staticmethod
+    def decode_labels(labels: Dict[str, AnyStr]) -> Dict[str, str]:
+        decoded_labels = {}
+        for key, value in labels.items():
+            if isinstance(value, bytes):
+                value = value.decode()
+            decoded_labels[key] = value
+        return decoded_labels
+
 
 def start_open_telemetry_observability(
     *,
@@ -220,19 +354,25 @@ class OpenTelemetryObservability(grpc._observability.ObservabilityPlugin):
     This is class is part of an EXPERIMENTAL API.
 
     Args:
-      plugin: _OpenTelemetryPlugin to enable.
+      plugins: _OpenTelemetryPlugins to enable.
     """
 
-    exporter: "grpc_observability.Exporter"
+    _exporter: "grpc_observability.Exporter"
+    _plugins: List[_OpenTelemetryPlugin]
     _registered_method: Set[bytes]
+    _client_option_activated: bool
+    _server_option_activated: bool
 
     def __init__(
         self,
         *,
         plugins: Optional[Iterable[_OpenTelemetryPlugin]],
     ):
-        self.exporter = _OpenTelemetryExporterDelegator(plugins)
+        self._exporter = _OpenTelemetryExporterDelegator(plugins)
         self._registered_methods = set()
+        self._plugins = plugins
+        self._client_option_activated = False
+        self._server_option_activated = False
 
     def observability_init(self):
         try:
@@ -242,7 +382,7 @@ class OpenTelemetryObservability(grpc._observability.ObservabilityPlugin):
             raise ValueError(f"Activate observability metrics failed with: {e}")
 
         try:
-            _cyobservability.cyobservability_init(self.exporter)
+            _cyobservability.cyobservability_init(self._exporter)
         # TODO(xuanwn): Use specific exceptons
         except Exception as e:  # pylint: disable=broad-except
             _LOGGER.exception("Initiate observability failed with: %s", e)
@@ -268,25 +408,36 @@ class OpenTelemetryObservability(grpc._observability.ObservabilityPlugin):
         self, method_name: bytes, target: bytes
     ) -> ClientCallTracerCapsule:
         trace_id = b"TRACE_ID"
-        registered_method = False
-        if method_name in self._registered_methods:
-            registered_method = True
+        self._maybe_activate_client_plugin_options(target)
+        exchange_labels = self._get_client_exchange_labels()
+        enabled_optional_labels = set()
+        for plugin in self._plugins:
+            enabled_optional_labels.update(plugin.get_enabled_optional_labels())
+
         capsule = _cyobservability.create_client_call_tracer(
-            method_name, target, trace_id, registered_method
+            method_name,
+            target,
+            trace_id,
+            self._get_identifier(),
+            exchange_labels,
+            enabled_optional_labels,
+            method_name in self._registered_methods,
         )
         return capsule
 
     def create_server_call_tracer_factory(
         self,
-    ) -> ServerCallTracerFactoryCapsule:
-        capsule = _cyobservability.create_server_call_tracer_factory_capsule()
+        *,
+        xds: bool = False,
+    ) -> Optional[ServerCallTracerFactoryCapsule]:
+        capsule = None
+        self._maybe_activate_server_plugin_options(xds)
+        exchange_labels = self._get_server_exchange_labels()
+        capsule = _cyobservability.create_server_call_tracer_factory_capsule(
+            exchange_labels, self._get_identifier()
+        )
         return capsule
 
-    def delete_client_call_tracer(
-        self, client_call_tracer: ClientCallTracerCapsule
-    ) -> None:
-        _cyobservability.delete_client_call_tracer(client_call_tracer)
-
     def save_trace_context(
         self, trace_id: str, span_id: str, is_sampled: bool
     ) -> None:
@@ -300,22 +451,53 @@ class OpenTelemetryObservability(grpc._observability.ObservabilityPlugin):
         status_code: grpc.StatusCode,
     ) -> None:
         status_code = GRPC_STATUS_CODE_TO_STRING.get(status_code, "UNKNOWN")
-        registered_method = False
         encoded_method = method.encode("utf8")
-        if encoded_method in self._registered_methods:
-            registered_method = True
         _cyobservability._record_rpc_latency(
-            self.exporter,
+            self._exporter,
             method,
             target,
             rpc_latency,
             status_code,
-            registered_method,
+            self._get_identifier(),
+            encoded_method in self._registered_methods,
         )
 
     def save_registered_method(self, method_name: bytes) -> None:
         self._registered_methods.add(method_name)
 
+    def _get_client_exchange_labels(self) -> Dict[str, AnyStr]:
+        client_exchange_labels = {}
+        for _plugin in self._plugins:
+            client_exchange_labels.update(_plugin.get_client_exchange_labels())
+        return client_exchange_labels
+
+    def _get_server_exchange_labels(self) -> Dict[str, AnyStr]:
+        server_exchange_labels = {}
+        for _plugin in self._plugins:
+            server_exchange_labels.update(_plugin.get_server_exchange_labels())
+        return server_exchange_labels
+
+    def _maybe_activate_client_plugin_options(self, target: bytes) -> None:
+        if not self._client_option_activated:
+            for _plugin in self._plugins:
+                _plugin.activate_client_plugin_options(target)
+            self._client_option_activated = True
+
+    def _maybe_activate_server_plugin_options(self, xds: bool) -> None:
+        if not self._server_option_activated:
+            for _plugin in self._plugins:
+                _plugin.activate_server_plugin_options(xds)
+            self._server_option_activated = True
+
+    def _get_identifier(self) -> str:
+        plugin_identifiers = []
+        for _plugin in self._plugins:
+            plugin_identifiers.append(_plugin.identifier)
+        return PLUGIN_IDENTIFIER_SEP.join(plugin_identifiers)
+
+    def get_enabled_optional_labels(self) -> List[OptionalLabelType]:
+        return []
+
 
 def _start_open_telemetry_observability(
     otel_o11y: OpenTelemetryObservability,
