@@ -21,6 +21,8 @@
 #include "absl/log/check.h"
 #include "gtest/gtest.h"
 
+#include "src/core/lib/gprpp/manual_constructor.h"
+#include "src/core/lib/gprpp/ref_counted.h"
 #include "test/core/test_util/test_config.h"
 
 namespace grpc_core {
@@ -115,6 +117,42 @@ TEST(DualRefCountedWithTracing, Basic) {
   foo->Unref(DEBUG_LOCATION, "original_ref");
 }
 
+class FooWithNoDelete final
+    : public DualRefCounted<FooWithNoDelete, NonPolymorphicRefCount,
+                            UnrefCallDtor> {
+ public:
+  FooWithNoDelete(bool* orphaned_called, bool* destructor_called)
+      : DualRefCounted<FooWithNoDelete, NonPolymorphicRefCount, UnrefCallDtor>(
+            "FooWithNoDelete"),
+        orphaned_called_(orphaned_called),
+        destructor_called_(destructor_called) {}
+  ~FooWithNoDelete() { *destructor_called_ = true; }
+
+  void Orphaned() override { *orphaned_called_ = true; }
+
+ private:
+  bool* const orphaned_called_;
+  bool* const destructor_called_;
+};
+
+TEST(DualRefCountedWithNoDelete, Basic) {
+  ManualConstructor<FooWithNoDelete> foo;
+  bool destructor_called = false;
+  bool orphaned_called = false;
+  foo.Init(&orphaned_called, &destructor_called);
+  EXPECT_FALSE(orphaned_called);
+  EXPECT_FALSE(destructor_called);
+  foo->WeakRef().release();
+  EXPECT_FALSE(orphaned_called);
+  EXPECT_FALSE(destructor_called);
+  foo->Unref();
+  EXPECT_TRUE(orphaned_called);
+  EXPECT_FALSE(destructor_called);
+  foo->WeakUnref();
+  EXPECT_TRUE(orphaned_called);
+  EXPECT_TRUE(destructor_called);
+}
+
 }  // namespace
 }  // namespace testing
 }  // namespace grpc_core
