@@ -22,17 +22,19 @@
 #include <string>
 
 #include "absl/log/check.h"
+#include "absl/log/log.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/string_view.h"
 #include "absl/types/variant.h"
 
 #include <grpc/grpc.h>
 #include <grpc/support/json.h>
-#include <grpc/support/log.h>
 
+#include "src/core/client_channel/lb_metadata.h"
 #include "src/core/lib/address_utils/parse_address.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/config/core_configuration.h"
+#include "src/core/lib/gprpp/down_cast.h"
 #include "src/core/lib/gprpp/orphanable.h"
 #include "src/core/lib/gprpp/ref_counted_ptr.h"
 #include "src/core/lib/gprpp/status_helper.h"
@@ -40,8 +42,6 @@
 #include "src/core/lib/iomgr/error.h"
 #include "src/core/lib/iomgr/pollset_set.h"
 #include "src/core/lib/iomgr/resolved_address.h"
-#include "src/core/lib/json/json.h"
-#include "src/core/lib/json/json_util.h"
 #include "src/core/lib/uri/uri_parser.h"
 #include "src/core/load_balancing/delegating_helper.h"
 #include "src/core/load_balancing/lb_policy.h"
@@ -49,6 +49,8 @@
 #include "src/core/load_balancing/lb_policy_registry.h"
 #include "src/core/load_balancing/oob_backend_metric.h"
 #include "src/core/load_balancing/subchannel_interface.h"
+#include "src/core/util/json/json.h"
+#include "src/core/util/json/json_util.h"
 
 namespace grpc_core {
 
@@ -129,7 +131,8 @@ class TestPickArgsLb : public ForwardingLoadBalancingPolicy {
       // Report args seen.
       PickArgsSeen args_seen;
       args_seen.path = std::string(args.path);
-      args_seen.metadata = args.initial_metadata->TestOnlyCopyToVector();
+      args_seen.metadata =
+          DownCast<LbMetadata*>(args.initial_metadata)->TestOnlyCopyToVector();
       cb_(args_seen);
       // Do pick.
       return delegate_picker_->Pick(args);
@@ -269,7 +272,8 @@ class InterceptRecvTrailingMetadataLoadBalancingPolicy
       args_seen.status = args.status;
       args_seen.backend_metric_data =
           args.backend_metric_accessor->GetBackendMetricData();
-      args_seen.metadata = args.trailing_metadata->TestOnlyCopyToVector();
+      args_seen.metadata =
+          DownCast<LbMetadata*>(args.trailing_metadata)->TestOnlyCopyToVector();
       cb_(args_seen);
     }
 
@@ -411,8 +415,8 @@ class FixedAddressLoadBalancingPolicy : public ForwardingLoadBalancingPolicy {
 
   absl::Status UpdateLocked(UpdateArgs args) override {
     auto* config = static_cast<FixedAddressConfig*>(args.config.get());
-    gpr_log(GPR_INFO, "%s: update URI: %s", kFixedAddressLbPolicyName,
-            config->address().c_str());
+    LOG(INFO) << kFixedAddressLbPolicyName
+              << ": update URI: " << config->address();
     auto uri = URI::Parse(config->address());
     args.config.reset();
     EndpointAddressesList addresses;
@@ -421,9 +425,8 @@ class FixedAddressLoadBalancingPolicy : public ForwardingLoadBalancingPolicy {
       CHECK(grpc_parse_uri(*uri, &address));
       addresses.emplace_back(address, ChannelArgs());
     } else {
-      gpr_log(GPR_ERROR,
-              "%s: could not parse URI (%s), using empty address list",
-              kFixedAddressLbPolicyName, uri.status().ToString().c_str());
+      LOG(ERROR) << kFixedAddressLbPolicyName << ": could not parse URI ("
+                 << uri.status().ToString() << "), using empty address list";
       args.resolution_note = "no address in fixed_address_lb policy";
     }
     args.addresses =
@@ -716,6 +719,102 @@ class QueueOnceLoadBalancingPolicyFactory : public LoadBalancingPolicyFactory {
   }
 };
 
+//
+// AuthorityOverrideLbPolicy: A load balancing policy that delegates to
+// pick_first but adds an authority override on completed picks.
+//
+
+constexpr char kAuthorityOverridePolicyName[] = "authority_override_lb";
+
+class AuthorityOverrideLoadBalancingPolicy
+    : public ForwardingLoadBalancingPolicy {
+ public:
+  explicit AuthorityOverrideLoadBalancingPolicy(Args args)
+      : ForwardingLoadBalancingPolicy(
+            std::make_unique<Helper>(
+                RefCountedPtr<AuthorityOverrideLoadBalancingPolicy>(this)),
+            std::move(args), "pick_first",
+            /*initial_refcount=*/2) {}
+
+  absl::string_view name() const override {
+    return kAuthorityOverridePolicyName;
+  }
+
+  absl::Status UpdateLocked(UpdateArgs args) override {
+    authority_override_ =
+        grpc_event_engine::experimental::Slice::FromCopiedString(
+            args.args.GetString(GRPC_ARG_TEST_LB_AUTHORITY_OVERRIDE)
+                .value_or(""));
+    return ForwardingLoadBalancingPolicy::UpdateLocked(std::move(args));
+  }
+
+ private:
+  class Picker : public SubchannelPicker {
+   public:
+    Picker(RefCountedPtr<SubchannelPicker> picker,
+           grpc_event_engine::experimental::Slice authority_override)
+        : picker_(std::move(picker)),
+          authority_override_(std::move(authority_override)) {}
+
+    PickResult Pick(PickArgs args) override {
+      auto pick_result = picker_->Pick(args);
+      auto* complete_pick =
+          absl::get_if<PickResult::Complete>(&pick_result.result);
+      if (complete_pick != nullptr) {
+        complete_pick->authority_override = authority_override_.Ref();
+      }
+      return pick_result;
+    }
+
+   private:
+    RefCountedPtr<SubchannelPicker> picker_;
+    grpc_event_engine::experimental::Slice authority_override_;
+  };
+
+  class Helper : public ParentOwningDelegatingChannelControlHelper<
+                     AuthorityOverrideLoadBalancingPolicy> {
+   public:
+    explicit Helper(RefCountedPtr<AuthorityOverrideLoadBalancingPolicy> parent)
+        : ParentOwningDelegatingChannelControlHelper(std::move(parent)) {}
+
+    void UpdateState(grpc_connectivity_state state, const absl::Status& status,
+                     RefCountedPtr<SubchannelPicker> picker) override {
+      parent_helper()->UpdateState(
+          state, status,
+          MakeRefCounted<Picker>(std::move(picker),
+                                 parent()->authority_override_.Ref()));
+    }
+  };
+
+  grpc_event_engine::experimental::Slice authority_override_;
+};
+
+class AuthorityOverrideLbConfig : public LoadBalancingPolicy::Config {
+ public:
+  absl::string_view name() const override {
+    return kAuthorityOverridePolicyName;
+  }
+};
+
+class AuthorityOverrideLoadBalancingPolicyFactory
+    : public LoadBalancingPolicyFactory {
+ public:
+  OrphanablePtr<LoadBalancingPolicy> CreateLoadBalancingPolicy(
+      LoadBalancingPolicy::Args args) const override {
+    return MakeOrphanable<AuthorityOverrideLoadBalancingPolicy>(
+        std::move(args));
+  }
+
+  absl::string_view name() const override {
+    return kAuthorityOverridePolicyName;
+  }
+
+  absl::StatusOr<RefCountedPtr<LoadBalancingPolicy::Config>>
+  ParseLoadBalancingConfig(const Json& /*json*/) const override {
+    return MakeRefCounted<AuthorityOverrideLbConfig>();
+  }
+};
+
 }  // namespace
 
 void RegisterTestPickArgsLoadBalancingPolicy(
@@ -763,4 +862,10 @@ void RegisterQueueOnceLoadBalancingPolicy(CoreConfiguration::Builder* builder) {
       std::make_unique<QueueOnceLoadBalancingPolicyFactory>());
 }
 
+void RegisterAuthorityOverrideLoadBalancingPolicy(
+    CoreConfiguration::Builder* builder) {
+  builder->lb_policy_registry()->RegisterLoadBalancingPolicyFactory(
+      std::make_unique<AuthorityOverrideLoadBalancingPolicyFactory>());
+}
+
 }  // namespace grpc_core
