@@ -34,11 +34,12 @@
 #include <grpc/grpc.h>
 #include <grpc/status.h>
 #include <grpc/support/json.h>
-#include <grpc/support/log.h>
 #include <grpcpp/impl/codegen/config_protobuf.h>
 
 #include "src/core/ext/filters/fault_injection/fault_injection_filter.h"
 #include "src/core/ext/filters/fault_injection/fault_injection_service_config_parser.h"
+#include "src/core/ext/filters/gcp_authentication/gcp_authentication_filter.h"
+#include "src/core/ext/filters/gcp_authentication/gcp_authentication_service_config_parser.h"
 #include "src/core/ext/filters/rbac/rbac_filter.h"
 #include "src/core/ext/filters/rbac/rbac_service_config_parser.h"
 #include "src/core/ext/filters/stateful_session/stateful_session_filter.h"
@@ -56,6 +57,7 @@
 #include "src/proto/grpc/testing/xds/v3/extension.pb.h"
 #include "src/proto/grpc/testing/xds/v3/fault.pb.h"
 #include "src/proto/grpc/testing/xds/v3/fault_common.pb.h"
+#include "src/proto/grpc/testing/xds/v3/gcp_authn.pb.h"
 #include "src/proto/grpc/testing/xds/v3/http_filter_rbac.pb.h"
 #include "src/proto/grpc/testing/xds/v3/metadata.pb.h"
 #include "src/proto/grpc/testing/xds/v3/path.pb.h"
@@ -79,13 +81,14 @@ namespace testing {
 namespace {
 
 using ::envoy::extensions::filters::http::fault::v3::HTTPFault;
+using ::envoy::extensions::filters::http::gcp_authn::v3::GcpAuthnFilterConfig;
 using ::envoy::extensions::filters::http::rbac::v3::RBAC;
 using ::envoy::extensions::filters::http::rbac::v3::RBACPerRoute;
 using ::envoy::extensions::filters::http::router::v3::Router;
 using ::envoy::extensions::filters::http::stateful_session::v3::StatefulSession;
-using ::envoy::extensions::filters::http::stateful_session::v3 ::
+using ::envoy::extensions::filters::http::stateful_session::v3::
     StatefulSessionPerRoute;
-using ::envoy::extensions::http::stateful_session::cookie::v3 ::
+using ::envoy::extensions::http::stateful_session::cookie::v3::
     CookieBasedSessionState;
 
 //
@@ -210,7 +213,7 @@ TEST_F(XdsRouterFilterTest, Accessors) {
 
 TEST_F(XdsRouterFilterTest, GenerateFilterConfig) {
   XdsExtension extension = MakeXdsExtension(Router());
-  auto config = filter_->GenerateFilterConfig(decode_context_,
+  auto config = filter_->GenerateFilterConfig("", decode_context_,
                                               std::move(extension), &errors_);
   ASSERT_TRUE(errors_.ok()) << errors_.status(
       absl::StatusCode::kInvalidArgument, "unexpected errors");
@@ -222,7 +225,7 @@ TEST_F(XdsRouterFilterTest, GenerateFilterConfig) {
 TEST_F(XdsRouterFilterTest, GenerateFilterConfigTypedStruct) {
   XdsExtension extension = MakeXdsExtension(Router());
   extension.value = Json();
-  auto config = filter_->GenerateFilterConfig(decode_context_,
+  auto config = filter_->GenerateFilterConfig("", decode_context_,
                                               std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
@@ -239,7 +242,7 @@ TEST_F(XdsRouterFilterTest, GenerateFilterConfigUnparseable) {
   XdsExtension extension = MakeXdsExtension(Router());
   std::string serialized_resource("\0", 1);
   extension.value = absl::string_view(serialized_resource);
-  auto config = filter_->GenerateFilterConfig(decode_context_,
+  auto config = filter_->GenerateFilterConfig("", decode_context_,
                                               std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
@@ -255,7 +258,7 @@ TEST_F(XdsRouterFilterTest, GenerateFilterConfigUnparseable) {
 TEST_F(XdsRouterFilterTest, GenerateFilterConfigOverride) {
   XdsExtension extension = MakeXdsExtension(Router());
   auto config = filter_->GenerateFilterConfigOverride(
-      decode_context_, std::move(extension), &errors_);
+      "", decode_context_, std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
   EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
@@ -299,28 +302,37 @@ TEST_F(XdsFaultInjectionFilterTest, ModifyChannelArgs) {
   EXPECT_EQ(*value, 1);
 }
 
-TEST_F(XdsFaultInjectionFilterTest, GenerateServiceConfigTopLevelConfig) {
+TEST_F(XdsFaultInjectionFilterTest, GenerateMethodConfigTopLevelConfig) {
   XdsHttpFilterImpl::FilterConfig config;
   config.config = Json::FromObject({{"foo", Json::FromString("bar")}});
-  auto service_config = filter_->GenerateServiceConfig(config, nullptr);
+  auto service_config = filter_->GenerateMethodConfig(config, nullptr);
   ASSERT_TRUE(service_config.ok()) << service_config.status();
   EXPECT_EQ(service_config->service_config_field_name, "faultInjectionPolicy");
   EXPECT_EQ(service_config->element, "{\"foo\":\"bar\"}");
 }
 
-TEST_F(XdsFaultInjectionFilterTest, GenerateServiceConfigOverrideConfig) {
+TEST_F(XdsFaultInjectionFilterTest, GenerateMethodConfigOverrideConfig) {
   XdsHttpFilterImpl::FilterConfig top_config;
   top_config.config = Json::FromObject({{"foo", Json::FromString("bar")}});
   XdsHttpFilterImpl::FilterConfig override_config;
   override_config.config =
       Json::FromObject({{"baz", Json::FromString("quux")}});
   auto service_config =
-      filter_->GenerateServiceConfig(top_config, &override_config);
+      filter_->GenerateMethodConfig(top_config, &override_config);
   ASSERT_TRUE(service_config.ok()) << service_config.status();
   EXPECT_EQ(service_config->service_config_field_name, "faultInjectionPolicy");
   EXPECT_EQ(service_config->element, "{\"baz\":\"quux\"}");
 }
 
+TEST_F(XdsFaultInjectionFilterTest, GenerateServiceConfig) {
+  XdsHttpFilterImpl::FilterConfig config;
+  config.config = Json::FromObject({{"foo", Json::FromString("bar")}});
+  auto service_config = filter_->GenerateServiceConfig(config);
+  ASSERT_TRUE(service_config.ok()) << service_config.status();
+  EXPECT_EQ(service_config->service_config_field_name, "");
+  EXPECT_EQ(service_config->element, "");
+}
+
 // For the fault injection filter, GenerateFilterConfig() and
 // GenerateFilterConfigOverride() accept the same input, so we want to
 // run all tests for both.
@@ -332,10 +344,10 @@ class XdsFaultInjectionFilterConfigTest
       XdsExtension extension) {
     if (GetParam()) {
       return filter_->GenerateFilterConfigOverride(
-          decode_context_, std::move(extension), &errors_);
+          "", decode_context_, std::move(extension), &errors_);
     }
-    return filter_->GenerateFilterConfig(decode_context_, std::move(extension),
-                                         &errors_);
+    return filter_->GenerateFilterConfig("", decode_context_,
+                                         std::move(extension), &errors_);
   }
 };
 
@@ -507,7 +519,7 @@ TEST_F(XdsRbacFilterTest, ModifyChannelArgs) {
 
 TEST_F(XdsRbacFilterTest, GenerateFilterConfig) {
   XdsExtension extension = MakeXdsExtension(RBAC());
-  auto config = filter_->GenerateFilterConfig(decode_context_,
+  auto config = filter_->GenerateFilterConfig("", decode_context_,
                                               std::move(extension), &errors_);
   ASSERT_TRUE(errors_.ok()) << errors_.status(
       absl::StatusCode::kInvalidArgument, "unexpected errors");
@@ -519,7 +531,7 @@ TEST_F(XdsRbacFilterTest, GenerateFilterConfig) {
 TEST_F(XdsRbacFilterTest, GenerateFilterConfigTypedStruct) {
   XdsExtension extension = MakeXdsExtension(RBAC());
   extension.value = Json();
-  auto config = filter_->GenerateFilterConfig(decode_context_,
+  auto config = filter_->GenerateFilterConfig("", decode_context_,
                                               std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
@@ -536,7 +548,7 @@ TEST_F(XdsRbacFilterTest, GenerateFilterConfigUnparseable) {
   XdsExtension extension = MakeXdsExtension(RBAC());
   std::string serialized_resource("\0", 1);
   extension.value = absl::string_view(serialized_resource);
-  auto config = filter_->GenerateFilterConfig(decode_context_,
+  auto config = filter_->GenerateFilterConfig("", decode_context_,
                                               std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
@@ -552,7 +564,7 @@ TEST_F(XdsRbacFilterTest, GenerateFilterConfigUnparseable) {
 TEST_F(XdsRbacFilterTest, GenerateFilterConfigOverride) {
   XdsExtension extension = MakeXdsExtension(RBACPerRoute());
   auto config = filter_->GenerateFilterConfigOverride(
-      decode_context_, std::move(extension), &errors_);
+      "", decode_context_, std::move(extension), &errors_);
   ASSERT_TRUE(errors_.ok()) << errors_.status(
       absl::StatusCode::kInvalidArgument, "unexpected errors");
   ASSERT_TRUE(config.has_value());
@@ -564,7 +576,7 @@ TEST_F(XdsRbacFilterTest, GenerateFilterConfigOverrideTypedStruct) {
   XdsExtension extension = MakeXdsExtension(RBACPerRoute());
   extension.value = Json();
   auto config = filter_->GenerateFilterConfigOverride(
-      decode_context_, std::move(extension), &errors_);
+      "", decode_context_, std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
   EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
@@ -580,7 +592,7 @@ TEST_F(XdsRbacFilterTest, GenerateFilterConfigOverrideUnparseable) {
   std::string serialized_resource("\0", 1);
   extension.value = absl::string_view(serialized_resource);
   auto config = filter_->GenerateFilterConfigOverride(
-      decode_context_, std::move(extension), &errors_);
+      "", decode_context_, std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
   EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
@@ -591,17 +603,26 @@ TEST_F(XdsRbacFilterTest, GenerateFilterConfigOverrideUnparseable) {
       << status;
 }
 
-TEST_F(XdsRbacFilterTest, GenerateServiceConfig) {
+TEST_F(XdsRbacFilterTest, GenerateMethodConfig) {
   XdsHttpFilterImpl::FilterConfig hcm_config = {
       filter_->ConfigProtoName(),
       Json::FromObject({{"name", Json::FromString("foo")}})};
-  auto config = filter_->GenerateServiceConfig(hcm_config, nullptr);
+  auto config = filter_->GenerateMethodConfig(hcm_config, nullptr);
   ASSERT_TRUE(config.ok()) << config.status();
   EXPECT_EQ(config->service_config_field_name, "rbacPolicy");
   EXPECT_EQ(config->element,
             JsonDump(Json::FromObject({{"name", Json::FromString("foo")}})));
 }
 
+TEST_F(XdsRbacFilterTest, GenerateServiceConfig) {
+  XdsHttpFilterImpl::FilterConfig config;
+  config.config = Json::FromObject({{"foo", Json::FromString("bar")}});
+  auto service_config = filter_->GenerateServiceConfig(config);
+  ASSERT_TRUE(service_config.ok()) << service_config.status();
+  EXPECT_EQ(service_config->service_config_field_name, "");
+  EXPECT_EQ(service_config->element, "");
+}
+
 // For the RBAC filter, the override config is a superset of the
 // top-level config, so we test all of the common fields as input for
 // both GenerateFilterConfig() and GenerateFilterConfigOverride().
@@ -614,11 +635,11 @@ class XdsRbacFilterConfigTest : public XdsRbacFilterTest,
       *rbac_per_route.mutable_rbac() = rbac;
       XdsExtension extension = MakeXdsExtension(rbac_per_route);
       return filter_->GenerateFilterConfigOverride(
-          decode_context_, std::move(extension), &errors_);
+          "", decode_context_, std::move(extension), &errors_);
     }
     XdsExtension extension = MakeXdsExtension(rbac);
-    return filter_->GenerateFilterConfig(decode_context_, std::move(extension),
-                                         &errors_);
+    return filter_->GenerateFilterConfig("", decode_context_,
+                                         std::move(extension), &errors_);
   }
 
   std::string FieldPrefix() {
@@ -1139,7 +1160,7 @@ TEST_F(XdsStatefulSessionFilterTest, OverrideConfigDisabled) {
   stateful_session_per_route.set_disabled(true);
   XdsExtension extension = MakeXdsExtension(stateful_session_per_route);
   auto config = filter_->GenerateFilterConfigOverride(
-      decode_context_, std::move(extension), &errors_);
+      "", decode_context_, std::move(extension), &errors_);
   ASSERT_TRUE(errors_.ok()) << errors_.status(
       absl::StatusCode::kInvalidArgument, "unexpected errors");
   ASSERT_TRUE(config.has_value());
@@ -1147,35 +1168,44 @@ TEST_F(XdsStatefulSessionFilterTest, OverrideConfigDisabled) {
   EXPECT_EQ(config->config, Json::FromObject({})) << JsonDump(config->config);
 }
 
-TEST_F(XdsStatefulSessionFilterTest, GenerateServiceConfigNoOverride) {
+TEST_F(XdsStatefulSessionFilterTest, GenerateMethodConfigNoOverride) {
   XdsHttpFilterImpl::FilterConfig hcm_config = {
       filter_->ConfigProtoName(),
       Json::FromObject({{"name", Json::FromString("foo")}})};
-  auto config = filter_->GenerateServiceConfig(hcm_config, nullptr);
+  auto config = filter_->GenerateMethodConfig(hcm_config, nullptr);
   ASSERT_TRUE(config.ok()) << config.status();
   EXPECT_EQ(config->service_config_field_name, "stateful_session");
   EXPECT_EQ(config->element,
             JsonDump(Json::FromObject({{"name", Json::FromString("foo")}})));
 }
 
-TEST_F(XdsStatefulSessionFilterTest, GenerateServiceConfigWithOverride) {
+TEST_F(XdsStatefulSessionFilterTest, GenerateMethodConfigWithOverride) {
   XdsHttpFilterImpl::FilterConfig hcm_config = {
       filter_->ConfigProtoName(),
       Json::FromObject({{"name", Json::FromString("foo")}})};
   XdsHttpFilterImpl::FilterConfig override_config = {
       filter_->OverrideConfigProtoName(),
       Json::FromObject({{"name", Json::FromString("bar")}})};
-  auto config = filter_->GenerateServiceConfig(hcm_config, &override_config);
+  auto config = filter_->GenerateMethodConfig(hcm_config, &override_config);
   ASSERT_TRUE(config.ok()) << config.status();
   EXPECT_EQ(config->service_config_field_name, "stateful_session");
   EXPECT_EQ(config->element,
             JsonDump(Json::FromObject({{"name", Json::FromString("bar")}})));
 }
 
+TEST_F(XdsStatefulSessionFilterTest, GenerateServiceConfig) {
+  XdsHttpFilterImpl::FilterConfig config;
+  config.config = Json::FromObject({{"foo", Json::FromString("bar")}});
+  auto service_config = filter_->GenerateServiceConfig(config);
+  ASSERT_TRUE(service_config.ok()) << service_config.status();
+  EXPECT_EQ(service_config->service_config_field_name, "");
+  EXPECT_EQ(service_config->element, "");
+}
+
 TEST_F(XdsStatefulSessionFilterTest, GenerateFilterConfigTypedStruct) {
   XdsExtension extension = MakeXdsExtension(StatefulSession());
   extension.value = Json();
-  auto config = filter_->GenerateFilterConfig(decode_context_,
+  auto config = filter_->GenerateFilterConfig("", decode_context_,
                                               std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
@@ -1193,7 +1223,7 @@ TEST_F(XdsStatefulSessionFilterTest, GenerateFilterConfigUnparseable) {
   XdsExtension extension = MakeXdsExtension(StatefulSession());
   std::string serialized_resource("\0", 1);
   extension.value = absl::string_view(serialized_resource);
-  auto config = filter_->GenerateFilterConfig(decode_context_,
+  auto config = filter_->GenerateFilterConfig("", decode_context_,
                                               std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
@@ -1211,7 +1241,7 @@ TEST_F(XdsStatefulSessionFilterTest, GenerateFilterConfigOverrideTypedStruct) {
   XdsExtension extension = MakeXdsExtension(StatefulSessionPerRoute());
   extension.value = Json();
   auto config = filter_->GenerateFilterConfigOverride(
-      decode_context_, std::move(extension), &errors_);
+      "", decode_context_, std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
   EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
@@ -1229,7 +1259,7 @@ TEST_F(XdsStatefulSessionFilterTest, GenerateFilterConfigOverrideUnparseable) {
   std::string serialized_resource("\0", 1);
   extension.value = absl::string_view(serialized_resource);
   auto config = filter_->GenerateFilterConfigOverride(
-      decode_context_, std::move(extension), &errors_);
+      "", decode_context_, std::move(extension), &errors_);
   absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
                                        "errors validating filter config");
   EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
@@ -1256,11 +1286,11 @@ class XdsStatefulSessionFilterConfigTest
       *stateful_session_per_route.mutable_stateful_session() = stateful_session;
       XdsExtension extension = MakeXdsExtension(stateful_session_per_route);
       return filter_->GenerateFilterConfigOverride(
-          decode_context_, std::move(extension), &errors_);
+          "", decode_context_, std::move(extension), &errors_);
     }
     XdsExtension extension = MakeXdsExtension(stateful_session);
-    return filter_->GenerateFilterConfig(decode_context_, std::move(extension),
-                                         &errors_);
+    return filter_->GenerateFilterConfig("", decode_context_,
+                                         std::move(extension), &errors_);
   }
 
   std::string FieldPrefix() {
@@ -1447,6 +1477,193 @@ TEST_P(XdsStatefulSessionFilterConfigTest, UnparseableSessionState) {
       << status;
 }
 
+//
+// GCP auth filter tests
+//
+
+using XdsGcpAuthnFilterNotRegisteredTest = XdsHttpFilterTest;
+
+TEST_F(XdsGcpAuthnFilterNotRegisteredTest, NotPresentWithoutEnvVar) {
+  XdsExtension extension = MakeXdsExtension(GcpAuthnFilterConfig());
+  EXPECT_EQ(GetFilter(extension.type), nullptr);
+}
+
+class XdsGcpAuthnFilterTest : public XdsHttpFilterTest {
+ protected:
+  XdsGcpAuthnFilterTest() {
+    // Re-initialize registry with env var set.
+    ScopedExperimentalEnvVar env_var(
+        "GRPC_EXPERIMENTAL_XDS_GCP_AUTHENTICATION_FILTER");
+    registry_ = XdsHttpFilterRegistry();
+    // Now the filter will be found in the registry.
+    XdsExtension extension = MakeXdsExtension(GcpAuthnFilterConfig());
+    filter_ = GetFilter(extension.type);
+    CHECK_NE(filter_, nullptr) << extension.type;
+  }
+
+  const XdsHttpFilterImpl* filter_;
+};
+
+TEST_F(XdsGcpAuthnFilterTest, Accessors) {
+  EXPECT_EQ(filter_->ConfigProtoName(),
+            "envoy.extensions.filters.http.gcp_authn.v3.GcpAuthnFilterConfig");
+  EXPECT_EQ(filter_->OverrideConfigProtoName(), "");
+  EXPECT_EQ(filter_->channel_filter(), &GcpAuthenticationFilter::kFilter);
+  EXPECT_TRUE(filter_->IsSupportedOnClients());
+  EXPECT_FALSE(filter_->IsSupportedOnServers());
+  EXPECT_FALSE(filter_->IsTerminalFilter());
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateFilterConfigEmpty) {
+  XdsExtension extension = MakeXdsExtension(GcpAuthnFilterConfig());
+  auto config = filter_->GenerateFilterConfig("enterprise", decode_context_,
+                                              std::move(extension), &errors_);
+  ASSERT_TRUE(errors_.ok()) << errors_.status(
+      absl::StatusCode::kInvalidArgument, "unexpected errors");
+  ASSERT_TRUE(config.has_value());
+  EXPECT_EQ(config->config_proto_type_name, filter_->ConfigProtoName());
+  EXPECT_EQ(config->config,
+            Json::FromObject(
+                {{"filter_instance_name", Json::FromString("enterprise")}}))
+      << JsonDump(config->config);
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateFilterConfigCacheSizeDefault) {
+  GcpAuthnFilterConfig proto;
+  proto.mutable_cache_config();
+  XdsExtension extension = MakeXdsExtension(proto);
+  auto config = filter_->GenerateFilterConfig("yorktown", decode_context_,
+                                              std::move(extension), &errors_);
+  ASSERT_TRUE(errors_.ok()) << errors_.status(
+      absl::StatusCode::kInvalidArgument, "unexpected errors");
+  ASSERT_TRUE(config.has_value());
+  EXPECT_EQ(config->config_proto_type_name, filter_->ConfigProtoName());
+  EXPECT_EQ(
+      config->config,
+      Json::FromObject({{"filter_instance_name", Json::FromString("yorktown")},
+                        {"cache_size", Json::FromNumber(10)}}))
+      << JsonDump(config->config);
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateFilterConfigCacheSize) {
+  GcpAuthnFilterConfig proto;
+  proto.mutable_cache_config()->mutable_cache_size()->set_value(6);
+  XdsExtension extension = MakeXdsExtension(proto);
+  auto config = filter_->GenerateFilterConfig("hornet", decode_context_,
+                                              std::move(extension), &errors_);
+  ASSERT_TRUE(errors_.ok()) << errors_.status(
+      absl::StatusCode::kInvalidArgument, "unexpected errors");
+  ASSERT_TRUE(config.has_value());
+  EXPECT_EQ(config->config_proto_type_name, filter_->ConfigProtoName());
+  EXPECT_EQ(
+      config->config,
+      Json::FromObject({{"filter_instance_name", Json::FromString("hornet")},
+                        {"cache_size", Json::FromNumber(6)}}))
+      << JsonDump(config->config);
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateFilterConfigCacheSizeZero) {
+  GcpAuthnFilterConfig proto;
+  proto.mutable_cache_config()->mutable_cache_size()->set_value(0);
+  XdsExtension extension = MakeXdsExtension(proto);
+  auto config = filter_->GenerateFilterConfig("ranger", decode_context_,
+                                              std::move(extension), &errors_);
+  absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
+                                       "errors validating filter config");
+  EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
+  EXPECT_EQ(status.message(),
+            "errors validating filter config: ["
+            "field:http_filter.value["
+            "envoy.extensions.filters.http.gcp_authn.v3.GcpAuthnFilterConfig]"
+            ".cache_config.cache_size "
+            "error:must be in the range (0, INT64_MAX)]")
+      << status;
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateFilterConfigCacheSizeTooBig) {
+  GcpAuthnFilterConfig proto;
+  proto.mutable_cache_config()->mutable_cache_size()->set_value(INT64_MAX);
+  XdsExtension extension = MakeXdsExtension(proto);
+  auto config = filter_->GenerateFilterConfig("langley", decode_context_,
+                                              std::move(extension), &errors_);
+  absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
+                                       "errors validating filter config");
+  EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
+  EXPECT_EQ(status.message(),
+            "errors validating filter config: ["
+            "field:http_filter.value["
+            "envoy.extensions.filters.http.gcp_authn.v3.GcpAuthnFilterConfig]"
+            ".cache_config.cache_size "
+            "error:must be in the range (0, INT64_MAX)]")
+      << status;
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateFilterConfigTypedStruct) {
+  XdsExtension extension = MakeXdsExtension(GcpAuthnFilterConfig());
+  extension.value = Json();
+  auto config = filter_->GenerateFilterConfig("lexington", decode_context_,
+                                              std::move(extension), &errors_);
+  absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
+                                       "errors validating filter config");
+  EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
+  EXPECT_EQ(status.message(),
+            "errors validating filter config: ["
+            "field:http_filter.value["
+            "envoy.extensions.filters.http.gcp_authn.v3.GcpAuthnFilterConfig] "
+            "error:could not parse GCP auth filter config]")
+      << status;
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateFilterConfigUnparseable) {
+  XdsExtension extension = MakeXdsExtension(GcpAuthnFilterConfig());
+  std::string serialized_resource("\0", 1);
+  extension.value = absl::string_view(serialized_resource);
+  auto config = filter_->GenerateFilterConfig("saratoga", decode_context_,
+                                              std::move(extension), &errors_);
+  absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
+                                       "errors validating filter config");
+  EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
+  EXPECT_EQ(status.message(),
+            "errors validating filter config: ["
+            "field:http_filter.value["
+            "envoy.extensions.filters.http.gcp_authn.v3.GcpAuthnFilterConfig] "
+            "error:could not parse GCP auth filter config]")
+      << status;
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateFilterConfigOverride) {
+  XdsExtension extension = MakeXdsExtension(GcpAuthnFilterConfig());
+  auto config = filter_->GenerateFilterConfigOverride(
+      "wasp", decode_context_, std::move(extension), &errors_);
+  absl::Status status = errors_.status(absl::StatusCode::kInvalidArgument,
+                                       "errors validating filter config");
+  EXPECT_EQ(status.code(), absl::StatusCode::kInvalidArgument);
+  EXPECT_EQ(status.message(),
+            "errors validating filter config: ["
+            "field:http_filter.value["
+            "envoy.extensions.filters.http.gcp_authn.v3.GcpAuthnFilterConfig] "
+            "error:GCP auth filter does not support config override]")
+      << status;
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateMethodConfig) {
+  XdsHttpFilterImpl::FilterConfig config;
+  config.config = Json::FromObject({{"foo", Json::FromString("bar")}});
+  auto service_config = filter_->GenerateMethodConfig(config, nullptr);
+  ASSERT_TRUE(service_config.ok()) << service_config.status();
+  EXPECT_EQ(service_config->service_config_field_name, "");
+  EXPECT_EQ(service_config->element, "");
+}
+
+TEST_F(XdsGcpAuthnFilterTest, GenerateServiceConfig) {
+  XdsHttpFilterImpl::FilterConfig config;
+  config.config = Json::FromObject({{"foo", Json::FromString("bar")}});
+  auto service_config = filter_->GenerateServiceConfig(config);
+  ASSERT_TRUE(service_config.ok()) << service_config.status();
+  EXPECT_EQ(service_config->service_config_field_name, "gcp_authentication");
+  EXPECT_EQ(service_config->element, "{\"foo\":\"bar\"}");
+}
+
 }  // namespace
 }  // namespace testing
 }  // namespace grpc_core
