@@ -20,14 +20,15 @@
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
 
+#include "absl/log/log.h"
 #include "absl/strings/match.h"
 #include "absl/strings/str_cat.h"
 
 #include "src/core/client_channel/backup_poller.h"
 #include "src/core/lib/address_utils/sockaddr_utils.h"
-#include "src/core/lib/channel/call_tracer.h"
 #include "src/core/lib/config/config_vars.h"
 #include "src/core/lib/surface/call.h"
+#include "src/core/telemetry/call_tracer.h"
 #include "src/proto/grpc/testing/xds/v3/orca_load_report.pb.h"
 #include "test/core/test_util/fake_stats_plugin.h"
 #include "test/core/test_util/scoped_env_var.h"
@@ -898,10 +899,10 @@ TEST_P(EdsTest, LocalityMapUpdateChurn) {
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
   // Wait for the first 3 backends to be ready.
   WaitForAllBackends(DEBUG_LOCATION, 0, 3);
-  gpr_log(GPR_INFO, "========= BEFORE FIRST BATCH ==========");
+  LOG(INFO) << "========= BEFORE FIRST BATCH ==========";
   // Send kNumRpcs RPCs.
   CheckRpcSendOk(DEBUG_LOCATION, kNumRpcs);
-  gpr_log(GPR_INFO, "========= DONE WITH FIRST BATCH ==========");
+  LOG(INFO) << "========= DONE WITH FIRST BATCH ==========";
   // The picking rates of the first 3 backends should be roughly equal to the
   // expectation.
   std::vector<double> locality_picked_rates;
@@ -912,8 +913,7 @@ TEST_P(EdsTest, LocalityMapUpdateChurn) {
   }
   const double kErrorTolerance = 0.2;
   for (size_t i = 0; i < 3; ++i) {
-    gpr_log(GPR_INFO, "Locality %" PRIuPTR " rate %f", i,
-            locality_picked_rates[i]);
+    LOG(INFO) << "Locality " << i << " rate " << locality_picked_rates[i];
     EXPECT_THAT(
         locality_picked_rates[i],
         ::testing::AllOf(
@@ -931,10 +931,10 @@ TEST_P(EdsTest, LocalityMapUpdateChurn) {
   // Wait until the locality update has been processed, as signaled by backend
   // 3 receiving a request.
   WaitForAllBackends(DEBUG_LOCATION, 3, 4);
-  gpr_log(GPR_INFO, "========= BEFORE SECOND BATCH ==========");
+  LOG(INFO) << "========= BEFORE SECOND BATCH ==========";
   // Send kNumRpcs RPCs.
   CheckRpcSendOk(DEBUG_LOCATION, kNumRpcs);
-  gpr_log(GPR_INFO, "========= DONE WITH SECOND BATCH ==========");
+  LOG(INFO) << "========= DONE WITH SECOND BATCH ==========";
   // Backend 0 no longer receives any request.
   EXPECT_EQ(0U, backends_[0]->backend_service()->request_count());
   // The picking rates of the last 3 backends should be roughly equal to the
@@ -946,8 +946,7 @@ TEST_P(EdsTest, LocalityMapUpdateChurn) {
         kNumRpcs);
   }
   for (size_t i = 1; i < 4; ++i) {
-    gpr_log(GPR_INFO, "Locality %" PRIuPTR " rate %f", i,
-            locality_picked_rates[i]);
+    LOG(INFO) << "Locality " << i << " rate " << locality_picked_rates[i];
     EXPECT_THAT(
         locality_picked_rates[i],
         ::testing::AllOf(
@@ -1091,14 +1090,14 @@ TEST_P(EdsTest, DropConfigUpdate) {
   args.drop_categories = {{kLbDropType, kDropPerMillionForLb}};
   balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
   // Send kNumRpcsLbOnly RPCs and count the drops.
-  gpr_log(GPR_INFO, "========= BEFORE FIRST BATCH ==========");
+  LOG(INFO) << "========= BEFORE FIRST BATCH ==========";
   size_t num_drops = SendRpcsAndCountFailuresWithMessage(
       DEBUG_LOCATION, kNumRpcsLbOnly, StatusCode::UNAVAILABLE,
       kStatusMessageDropPrefix);
-  gpr_log(GPR_INFO, "========= DONE WITH FIRST BATCH ==========");
+  LOG(INFO) << "========= DONE WITH FIRST BATCH ==========";
   // The drop rate should be roughly equal to the expectation.
   double seen_drop_rate = static_cast<double>(num_drops) / kNumRpcsLbOnly;
-  gpr_log(GPR_INFO, "First batch drop rate %f", seen_drop_rate);
+  LOG(INFO) << "First batch drop rate " << seen_drop_rate;
   EXPECT_THAT(seen_drop_rate,
               ::testing::DoubleNear(kDropRateForLb, kErrorTolerance));
   // The second ADS response contains two drop categories, send an update EDS
@@ -1128,14 +1127,14 @@ TEST_P(EdsTest, DropConfigUpdate) {
       },
       /*timeout_ms=*/40000);
   // Send kNumRpcsBoth RPCs and count the drops.
-  gpr_log(GPR_INFO, "========= BEFORE SECOND BATCH ==========");
+  LOG(INFO) << "========= BEFORE SECOND BATCH ==========";
   num_drops = SendRpcsAndCountFailuresWithMessage(DEBUG_LOCATION, kNumRpcsBoth,
                                                   StatusCode::UNAVAILABLE,
                                                   kStatusMessageDropPrefix);
-  gpr_log(GPR_INFO, "========= DONE WITH SECOND BATCH ==========");
+  LOG(INFO) << "========= DONE WITH SECOND BATCH ==========";
   // The new drop rate should be roughly equal to the expectation.
   seen_drop_rate = static_cast<double>(num_drops) / kNumRpcsBoth;
-  gpr_log(GPR_INFO, "Second batch drop rate %f", seen_drop_rate);
+  LOG(INFO) << "Second batch drop rate " << seen_drop_rate;
   EXPECT_THAT(seen_drop_rate, ::testing::DoubleNear(kDropRateForLbAndThrottle,
                                                     kErrorTolerance));
 }
@@ -1157,6 +1156,170 @@ TEST_P(EdsTest, DropAll) {
   EXPECT_EQ(num_drops, kNumRpcs);
 }
 
+class EdsAuthorityRewriteTest : public XdsEnd2endTest {
+ protected:
+  void SetUp() override {}  // Individual tests call InitClient().
+};
+
+INSTANTIATE_TEST_SUITE_P(XdsTest, EdsAuthorityRewriteTest,
+                         ::testing::Values(XdsTestType()), &XdsTestType::Name);
+
+TEST_P(EdsAuthorityRewriteTest, AutoAuthorityRewrite) {
+  grpc_core::testing::ScopedExperimentalEnvVar env(
+      "GRPC_EXPERIMENTAL_XDS_AUTHORITY_REWRITE");
+  constexpr char kAltAuthority1[] = "alt_authority1";
+  constexpr char kAltAuthority2[] = "alt_authority2";
+  // Note: We use InsecureCreds, since FakeCreds are too picky about
+  // what authority gets sent.
+  InitClient(MakeBootstrapBuilder().SetTrustedXdsServer(),
+             /*lb_expected_authority=*/"",
+             /*xds_resource_does_not_exist_timeout_ms=*/0,
+             /*balancer_authority_override=*/"", /*args=*/nullptr,
+             InsecureChannelCredentials());
+  // Set auto_host_rewrite in the RouteConfig.
+  RouteConfiguration new_route_config = default_route_config_;
+  new_route_config.mutable_virtual_hosts(0)
+      ->mutable_routes(0)
+      ->mutable_route()
+      ->mutable_auto_host_rewrite()
+      ->set_value(true);
+  SetRouteConfiguration(balancer_.get(), new_route_config);
+  // Create 3 backends.  Backend 0 does not have a hostname, but 1 and 2 do.
+  CreateAndStartBackends(3, /*xds_enabled=*/false, InsecureServerCredentials());
+  EdsResourceArgs args(
+      {{"locality0",
+        {
+            CreateEndpoint(0),
+            CreateEndpoint(1, ::envoy::config::core::v3::HealthStatus::UNKNOWN,
+                           /*lb_weight=*/1, /*additional_backend_indxes=*/{},
+                           /*hostname=*/kAltAuthority1),
+            CreateEndpoint(2, ::envoy::config::core::v3::HealthStatus::UNKNOWN,
+                           /*lb_weight=*/1, /*additional_backend_indxes=*/{},
+                           /*hostname=*/kAltAuthority2),
+        }}});
+  balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
+  WaitForAllBackends(DEBUG_LOCATION);
+  // Send one RPC for each backend, check the authority headers seen on
+  // the servers, and make sure we see the expected ones.
+  std::set<std::string> authorities_seen;
+  for (size_t i = 0; i < backends_.size(); ++i) {
+    EchoResponse response;
+    Status status = SendRpc(
+        RpcOptions().set_echo_host_from_authority_header(true), &response);
+    EXPECT_TRUE(status.ok()) << "code=" << status.error_code()
+                             << " message=" << status.error_message();
+    authorities_seen.insert(response.param().host());
+  }
+  EXPECT_THAT(
+      authorities_seen,
+      ::testing::ElementsAre(kAltAuthority1, kAltAuthority2, kServerName));
+}
+
+TEST_P(EdsAuthorityRewriteTest, NoRewriteWithoutEnvVar) {
+  constexpr char kAltAuthority[] = "alt_authority";
+  InitClient(MakeBootstrapBuilder().SetTrustedXdsServer());
+  // Set auto_host_rewrite in the RouteConfig.
+  RouteConfiguration new_route_config = default_route_config_;
+  new_route_config.mutable_virtual_hosts(0)
+      ->mutable_routes(0)
+      ->mutable_route()
+      ->mutable_auto_host_rewrite()
+      ->set_value(true);
+  SetRouteConfiguration(balancer_.get(), new_route_config);
+  // Create a backend with a hostname in EDS.
+  CreateAndStartBackends(1);
+  EdsResourceArgs args(
+      {{"locality0",
+        {CreateEndpoint(0, ::envoy::config::core::v3::HealthStatus::UNKNOWN,
+                        /*lb_weight=*/1, /*additional_backend_indxes=*/{},
+                        /*hostname=*/kAltAuthority)}}});
+  balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
+  // Send an RPC and check the authority seen on the server side.
+  EchoResponse response;
+  Status status = SendRpc(
+      RpcOptions().set_echo_host_from_authority_header(true), &response);
+  EXPECT_TRUE(status.ok()) << "code=" << status.error_code()
+                           << " message=" << status.error_message();
+  EXPECT_EQ(response.param().host(), kServerName);
+}
+
+TEST_P(EdsAuthorityRewriteTest, NoRewriteIfServerNotTrustedInBootstrap) {
+  grpc_core::testing::ScopedExperimentalEnvVar env(
+      "GRPC_EXPERIMENTAL_XDS_AUTHORITY_REWRITE");
+  constexpr char kAltAuthority[] = "alt_authority";
+  InitClient();
+  // Set auto_host_rewrite in the RouteConfig.
+  RouteConfiguration new_route_config = default_route_config_;
+  new_route_config.mutable_virtual_hosts(0)
+      ->mutable_routes(0)
+      ->mutable_route()
+      ->mutable_auto_host_rewrite()
+      ->set_value(true);
+  SetRouteConfiguration(balancer_.get(), new_route_config);
+  // Create a backend with a hostname in EDS.
+  CreateAndStartBackends(1);
+  EdsResourceArgs args(
+      {{"locality0",
+        {CreateEndpoint(0, ::envoy::config::core::v3::HealthStatus::UNKNOWN,
+                        /*lb_weight=*/1, /*additional_backend_indxes=*/{},
+                        /*hostname=*/kAltAuthority)}}});
+  balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
+  // Send an RPC and check the authority seen on the server side.
+  EchoResponse response;
+  Status status = SendRpc(
+      RpcOptions().set_echo_host_from_authority_header(true), &response);
+  EXPECT_TRUE(status.ok()) << "code=" << status.error_code()
+                           << " message=" << status.error_message();
+  EXPECT_EQ(response.param().host(), kServerName);
+}
+
+TEST_P(EdsAuthorityRewriteTest, NoRewriteIfNoHostnameInEds) {
+  grpc_core::testing::ScopedExperimentalEnvVar env(
+      "GRPC_EXPERIMENTAL_XDS_AUTHORITY_REWRITE");
+  InitClient(MakeBootstrapBuilder().SetTrustedXdsServer());
+  // Set auto_host_rewrite in the RouteConfig.
+  RouteConfiguration new_route_config = default_route_config_;
+  new_route_config.mutable_virtual_hosts(0)
+      ->mutable_routes(0)
+      ->mutable_route()
+      ->mutable_auto_host_rewrite()
+      ->set_value(true);
+  SetRouteConfiguration(balancer_.get(), new_route_config);
+  // Create a backend with no hostname in EDS.
+  CreateAndStartBackends(1);
+  EdsResourceArgs args({{"locality0", {CreateEndpoint(0)}}});
+  balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
+  // Send an RPC and check the authority seen on the server side.
+  EchoResponse response;
+  Status status = SendRpc(
+      RpcOptions().set_echo_host_from_authority_header(true), &response);
+  EXPECT_TRUE(status.ok()) << "code=" << status.error_code()
+                           << " message=" << status.error_message();
+  EXPECT_EQ(response.param().host(), kServerName);
+}
+
+TEST_P(EdsAuthorityRewriteTest, NoRewriteIfNotEnabledInRoute) {
+  grpc_core::testing::ScopedExperimentalEnvVar env(
+      "GRPC_EXPERIMENTAL_XDS_AUTHORITY_REWRITE");
+  constexpr char kAltAuthority[] = "alt_authority";
+  InitClient(MakeBootstrapBuilder().SetTrustedXdsServer());
+  // Create a backend with a hostname in EDS.
+  CreateAndStartBackends(1);
+  EdsResourceArgs args(
+      {{"locality0",
+        {CreateEndpoint(0, ::envoy::config::core::v3::HealthStatus::UNKNOWN,
+                        /*lb_weight=*/1, /*additional_backend_indxes=*/{},
+                        /*hostname=*/kAltAuthority)}}});
+  balancer_->ads_service()->SetEdsResource(BuildEdsResource(args));
+  // Send an RPC and check the authority seen on the server side.
+  EchoResponse response;
+  Status status = SendRpc(
+      RpcOptions().set_echo_host_from_authority_header(true), &response);
+  EXPECT_TRUE(status.ok()) << "code=" << status.error_code()
+                           << " message=" << status.error_message();
+  EXPECT_EQ(response.param().host(), kServerName);
+}
+
 //
 // EDS failover tests
 //
@@ -1268,9 +1431,9 @@ TEST_P(FailoverTest, ReportsConnectingDuringFailover) {
   // Allow the connection attempt to complete.
   hold->Resume();
   // Now the RPC should complete successfully.
-  gpr_log(GPR_INFO, "=== WAITING FOR RPC TO FINISH ===");
+  LOG(INFO) << "=== WAITING FOR RPC TO FINISH ===";
   Status status = rpc.GetStatus();
-  gpr_log(GPR_INFO, "=== RPC FINISHED ===");
+  LOG(INFO) << "=== RPC FINISHED ===";
   EXPECT_TRUE(status.ok()) << "code=" << status.error_code()
                            << " message=" << status.error_message();
 }
