@@ -39,12 +39,18 @@ class XdsBootstrapBuilder {
     ignore_resource_deletion_ = true;
     return *this;
   }
+  XdsBootstrapBuilder& SetTrustedXdsServer() {
+    trusted_xds_server_ = true;
+    return *this;
+  }
   XdsBootstrapBuilder& SetServers(absl::Span<const absl::string_view> servers) {
     servers_ = std::vector<std::string>(servers.begin(), servers.end());
     return *this;
   }
-  XdsBootstrapBuilder& SetXdsChannelCredentials(const std::string& type) {
+  XdsBootstrapBuilder& SetXdsChannelCredentials(
+      const std::string& type, const std::string& config = "") {
     xds_channel_creds_type_ = type;
+    xds_channel_creds_config_ = config;
     return *this;
   }
   XdsBootstrapBuilder& SetClientDefaultListenerResourceNameTemplate(
@@ -98,8 +104,10 @@ class XdsBootstrapBuilder {
   std::string MakeAuthorityText();
 
   bool ignore_resource_deletion_ = false;
+  bool trusted_xds_server_ = false;
   std::vector<std::string> servers_;
   std::string xds_channel_creds_type_ = "fake";
+  std::string xds_channel_creds_config_;
   std::string client_default_listener_resource_name_template_;
   std::map<std::string /*key*/, PluginInfo> plugins_;
   std::map<std::string /*authority_name*/, AuthorityInfo> authorities_;
@@ -211,16 +219,19 @@ class XdsResourceUtils {
                         ::envoy::config::core::v3::HealthStatus health_status =
                             ::envoy::config::core::v3::HealthStatus::UNKNOWN,
                         int lb_weight = 1,
-                        std::vector<int> additional_ports = {})
+                        std::vector<int> additional_ports = {},
+                        absl::string_view hostname = "")
           : port(port),
             health_status(health_status),
             lb_weight(lb_weight),
-            additional_ports(std::move(additional_ports)) {}
+            additional_ports(std::move(additional_ports)),
+            hostname(hostname) {}
 
       int port;
       ::envoy::config::core::v3::HealthStatus health_status;
       int lb_weight;
       std::vector<int> additional_ports;
+      std::string hostname;
     };
 
     // A locality.
