@@ -22,9 +22,9 @@
 #include <grpc/support/alloc.h>
 
 #include "src/core/lib/config/core_configuration.h"
-#include "src/core/lib/gpr/tmpfile.h"
 #include "src/core/lib/gprpp/env.h"
-#include "src/core/lib/json/json_reader.h"
+#include "src/core/util/json/json_reader.h"
+#include "src/core/util/tmpfile.h"
 #include "test/core/test_util/test_config.h"
 
 namespace grpc {
