@@ -35,7 +35,6 @@
 
 #include <grpc/grpc.h>
 #include <grpc/support/alloc.h>
-#include <grpc/support/log.h>
 #include <grpc/support/string_util.h>
 #include <grpc/support/time.h>
 #include <grpcpp/channel.h>
@@ -606,7 +605,7 @@ bool InteropClient::DoServerCompressedStreaming() {
         absl::StrFormat("(compression=%s; size=%d)",
                         compressions[i] ? "true" : "false", sizes[i]);
 
-    VLOG(2) << "Sending request streaming rpc " << log_suffix.c_str();
+    VLOG(2) << "Sending request streaming rpc " << log_suffix;
 
     ResponseParameters* const response_parameter =
         request.add_response_parameters();
@@ -997,9 +996,7 @@ bool InteropClient::DoOrcaPerRpc() {
   CHECK(report.has_value());
   CHECK(report->has_value());
   auto comparison_result = OrcaLoadReportsDiff(report->value(), *orca_report);
-  if (comparison_result.has_value()) {
-    gpr_assertion_failed(__FILE__, __LINE__, comparison_result->c_str());
-  }
+  LOG_IF(FATAL, comparison_result.has_value()) << comparison_result->c_str();
   CHECK(!load_report_tracker_.GetNextLoadReport().has_value());
   VLOG(2) << "orca per rpc successfully finished";
   return true;
