@@ -27,8 +27,8 @@
 #include <grpc/support/port_platform.h>
 #include <grpcpp/impl/grpc_library.h>
 
-#include "src/core/lib/debug/stats.h"
-#include "src/core/lib/debug/stats_data.h"
+#include "src/core/telemetry/stats.h"
+#include "src/core/telemetry/stats_data.h"
 
 class LibraryInitializer {
  public:
