@@ -25,6 +25,7 @@
 #include <gtest/gtest.h>
 
 #include "absl/log/check.h"
+#include "absl/log/log.h"
 #include "absl/memory/memory.h"
 #include "opencensus/stats/testing/test_utils.h"
 
@@ -174,9 +175,8 @@ class LbFeedbackTest : public LoadReporterTest {
                 DoubleNear(expected_qps, expected_qps * 0.3));
     ASSERT_THAT(static_cast<double>(lb_feedback.errors_per_second()),
                 DoubleNear(expected_eps, expected_eps * 0.3));
-    gpr_log(GPR_INFO,
-            "Verified LB feedback matches the samples of index [%zu, %zu).",
-            start, start + count);
+    LOG(INFO) << "Verified LB feedback matches the samples of index [" << start
+              << ", " << start + count << ").";
   }
 
   const std::vector<std::pair<double, double>> kQpsEpsSamples = {
@@ -487,11 +487,11 @@ TEST_F(LoadReportTest, BasicReport) {
   // First fetch.
   load_reporter_->FetchAndSample();
   load_reporter_->GenerateLoads(kHostname1, kLbId1);
-  gpr_log(GPR_INFO, "First load generated.");
+  LOG(INFO) << "First load generated.";
   // Second fetch.
   load_reporter_->FetchAndSample();
   load_reporter_->GenerateLoads(kHostname2, kLbId2);
-  gpr_log(GPR_INFO, "Second load generated.");
+  LOG(INFO) << "Second load generated.";
   // TODO(juanlishen): Verify the data.
 }
 
