@@ -133,21 +133,17 @@ tail${i}:
     switch (state) {
 % for i in range(0,n-1):
       case State::kState${i}: {
-        if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-          VLOG(2).AtLocation(whence.file(), whence.line())
+        GRPC_TRACE_VLOG(promise_primitives, 2).AtLocation(whence.file(), whence.line())
                 << "seq[" << this << "]: begin poll step ${i+1}/${n}";
-        }
         auto result = ${"prior."*(n-1-i)}current_promise();
         PromiseResult${i}* p = result.value_if_ready();
-        if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-          VLOG(2).AtLocation(whence.file(), whence.line())
+        GRPC_TRACE_VLOG(promise_primitives, 2).AtLocation(whence.file(), whence.line())
                 << "seq[" << this << "]: poll step ${i+1}/${n} gets "
                 << (p != nullptr
                     ? (PromiseResultTraits${i}::IsOk(*p)
                       ? "ready"
                       : absl::StrCat("early-error:", PromiseResultTraits${i}::ErrorString(*p)).c_str())
                     : "pending");
-        }
         if (p == nullptr) return Pending{};
         if (!PromiseResultTraits${i}::IsOk(*p)) {
           return PromiseResultTraits${i}::template ReturnValue<Result>(std::move(*p));
@@ -162,16 +158,12 @@ tail${i}:
 % endfor
       default:
       case State::kState${n-1}: {
-        if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-          VLOG(2).AtLocation(whence.file(), whence.line())
+        GRPC_TRACE_VLOG(promise_primitives, 2).AtLocation(whence.file(), whence.line())
                 << "seq[" << this << "]: begin poll step ${n}/${n}";
-        }
         auto result = current_promise();
-        if (GRPC_TRACE_FLAG_ENABLED(promise_primitives)) {
-          VLOG(2).AtLocation(whence.file(), whence.line())
+        GRPC_TRACE_VLOG(promise_primitives, 2).AtLocation(whence.file(), whence.line())
                 << "seq[" << this << "]: poll step ${n}/${n} gets "
                 << (result.ready()? "ready" : "pending");
-        }
         auto* p = result.value_if_ready();
         if (p == nullptr) return Pending{};
         return Result(std::move(*p));
