@@ -404,6 +404,7 @@ for dirname in [
     "test/core/call/yodel",
     "test/core/client_channel",
     "test/core/experiments",
+    "test/core/load_balancing",
     "test/core/uri",
     "test/core/test_util",
     "test/core/end2end",
@@ -430,6 +431,7 @@ for dirname in [
             "config_setting": lambda **kwargs: None,
             "selects": FakeSelects(),
             "python_config_settings": lambda **kwargs: None,
+            "grpc_cc_benchmark": grpc_cc_library,
             "grpc_cc_binary": grpc_cc_library,
             "grpc_cc_library": grpc_cc_library,
             "grpc_cc_test": grpc_cc_library,
@@ -486,7 +488,7 @@ if args.whats_left:
     )
 
 
-# Keeps track of all possible sets of dependencies that could satify the
+# Keeps track of all possible sets of dependencies that could satisfy the
 # problem. (models the list monad in Haskell!)
 class Choices:
     def __init__(self, library, substitutions):
