@@ -134,6 +134,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.62.0", ReleaseInfo()),
             ("v1.63.1", ReleaseInfo()),
             ("v1.64.1", ReleaseInfo()),
+            ("v1.65.0", ReleaseInfo()),
+            ("v1.66.0", ReleaseInfo()),
         ]
     ),
     "go": OrderedDict(
@@ -303,6 +305,7 @@ LANG_RELEASE_MATRIX = {
             ("v1.63.3", ReleaseInfo()),
             ("v1.64.1", ReleaseInfo()),
             ("v1.65.0", ReleaseInfo()),
+            ("v1.66.0", ReleaseInfo()),
         ]
     ),
     "java": OrderedDict(
@@ -799,6 +802,18 @@ LANG_RELEASE_MATRIX = {
                     runtimes=["python"], testcases_file="python__master"
                 ),
             ),
+            (
+                "v1.65.0",
+                ReleaseInfo(
+                    runtimes=["python"], testcases_file="python__master"
+                ),
+            ),
+            (
+                "v1.66.0",
+                ReleaseInfo(
+                    runtimes=["python"], testcases_file="python__master"
+                ),
+            ),
         ]
     ),
     "node": OrderedDict(
@@ -897,6 +912,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.62.0", ReleaseInfo()),
             ("v1.63.0", ReleaseInfo()),
             ("v1.64.0", ReleaseInfo()),
+            ("v1.65.0", ReleaseInfo()),
+            ("v1.66.0", ReleaseInfo()),
         ]
     ),
     "php": OrderedDict(
@@ -959,6 +976,8 @@ LANG_RELEASE_MATRIX = {
             ("v1.62.0", ReleaseInfo()),
             ("v1.63.0", ReleaseInfo()),
             ("v1.64.0", ReleaseInfo()),
+            ("v1.65.0", ReleaseInfo()),
+            ("v1.66.0", ReleaseInfo()),
         ]
     ),
     "csharp": OrderedDict(
